using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

using System.Diagnostics;
using System.Xml;        // for XmlTextReader and XmlValidatingReader
using System.Xml.Schema; // for XmlSchemaCollection (which is used later)
using System.IO;
using System.Globalization;
using System.Windows.Forms.Design;
using System.Configuration;
using System.Web;
using System.Text.RegularExpressions;

namespace QD_GUI
{
    public partial class MainWindow : Form
    {
        Dictionary<string, int> oDefaultHeight = new Dictionary<string, int>();

        // Constructor
        public MainWindow()
        {
            InitializeComponent();

            GetDefaultHeights();
        }

        private void GetDefaultHeights()
        {
            // Get the Height of the groupboxes in each tab index
            for (int i = 0; i <= 9; i++)
            {
                TableLayoutPanel oTableLayoutPanel = new TableLayoutPanel();
                Control.ControlCollection oControlCollection = new Control.ControlCollection(this.Owner);
                
                switch (i)
                {
                    case 0:
                        oTableLayoutPanel = tlpIndex0;
                        break;
                    case 1:
                        oTableLayoutPanel = tlpIndex1;
                        break;
                    case 2:
                        oTableLayoutPanel = tlpIndex2;
                        break;
                    case 3:
                        oTableLayoutPanel = tlpIndex3;
                        break;
                    case 4:
                        oTableLayoutPanel = tlpIndex4;
                        break;
                    case 5:
                        oTableLayoutPanel = tlpIndex5;
                        break;
                    case 6:
                        oTableLayoutPanel = tlpIndex6;
                        break;
                    case 7:
                        oTableLayoutPanel = tlpIndex7;
                        break;
                    case 8:
                        oTableLayoutPanel = tlpIndex8;
                        break;
                    case 9:
                        oTableLayoutPanel = tlpIndex9;
                        break;
                }

                string sKey = oTableLayoutPanel.Name;
                int iValue = oTableLayoutPanel.Height;

                Debug.WriteLine("Adding DefaultHeight for: " + sKey + " Value: " + iValue);
                oDefaultHeight.Add(sKey, iValue);

                foreach (Control oControl in oTableLayoutPanel.Controls)
                {
                    sKey = oControl.Name;
                    iValue = oControl.Height;

                    Debug.WriteLine("Adding DefaultHeight for: " + sKey + " Value: "+ iValue);
                    oDefaultHeight.Add(sKey, iValue);
                }
            }
        }

        private void SetDefaultHeights()
        {
            // Get the Height of the groupboxes in each tab index
            for (int i = 0; i <= 9; i++)
            {
                TableLayoutPanel oTableLayoutPanel = new TableLayoutPanel();
                Control.ControlCollection oControlCollection = new Control.ControlCollection(this.Owner);

                switch (i)
                {
                    case 0:
                        oTableLayoutPanel = tlpIndex0;
                        break;
                    case 1:
                        oTableLayoutPanel = tlpIndex1;
                        break;
                    case 2:
                        oTableLayoutPanel = tlpIndex2;
                        break;
                    case 3:
                        oTableLayoutPanel = tlpIndex3;
                        break;
                    case 4:
                        oTableLayoutPanel = tlpIndex4;
                        break;
                    case 5:
                        oTableLayoutPanel = tlpIndex5;
                        break;
                    case 6:
                        oTableLayoutPanel = tlpIndex6;
                        break;
                    case 7:
                        oTableLayoutPanel = tlpIndex7;
                        break;
                    case 8:
                        oTableLayoutPanel = tlpIndex8;
                        break;
                    case 9:
                        oTableLayoutPanel = tlpIndex9;
                        break;
                }

                string sKey = oTableLayoutPanel.Name;
                int iValue = 0;
                oDefaultHeight.TryGetValue(sKey, out iValue);

                Debug.WriteLine("Setting DefaultHeight for: " + sKey + " Value: " + iValue);
                oTableLayoutPanel.Height = iValue;

                foreach (Control oControl in oTableLayoutPanel.Controls)
                {
                    sKey = oControl.Name;
                    oDefaultHeight.TryGetValue(sKey, out iValue);

                    Debug.WriteLine("Setting DefaultHeight for: " + sKey + " Value: " + iValue);
                    oControl.Height = iValue;
                }
            }
        }

        private void btnRunQD_Click(object sender, EventArgs e)
        {
            //////////////////////////////////////////////
            // Create object to be constructed from the XML file content
            QueueDump oQueueDump = new QueueDump();

            // run qd and grab its output
            QueueDumpUtil oQueueDumpUtil = new QueueDumpUtil();
            oQueueDumpUtil.FahDirectory = txtFahDirectory.Text;
            string sOutput = oQueueDumpUtil.Run();

            // check for output
            if (!String.IsNullOrEmpty(sOutput))
            {
                // save the output to a file
                bool isSuccess = false;
                try
                {
                    oQueueDumpUtil.SaveXmlToFile(txtQueueDumpFile.Text);
                    isSuccess = true;
                }
                catch (UnauthorizedAccessException oException)
                {
                    StringBuilder oString = new StringBuilder();
                    oString.Append("Error: You do not have permission to access the file: ");
                    oString.Append(txtQueueDumpFile.Text);
                    oString.Append("\r\n");
                    oString.Append("Select a different location to save the Queue Dump XML File to.\r\n");
                    oString.Append("\r\nError Message:\r\n");
                    oString.Append(oException.Message);

                    MessageBox.Show(oString.ToString());
                    btnQueueDumpBrowse.Focus();

                    isSuccess = false;
                }

                if (isSuccess == true)
                {
                    try
                    {
                        this.Cursor = Cursors.WaitCursor;

                        // Parse the XML file and create an object from it
                        oQueueDump = XmlQueueDump.ParseXmlFile(txtQueueDumpFile.Text, oQueueDump);
                        if (!String.IsNullOrEmpty(oQueueDump.Error))
                        {
                            throw new Exception(oQueueDump.Error);
                        }
                        oQueueDump.QDInfo = QDInfo.ParseFile(Properties.Settings.Default.qdinfo_FileName, oQueueDump.QDInfo);

                        // set the controls to the values from the QueueDump object
                        SetControls(oQueueDump);

                        this.Cursor = Cursors.Default;

                        // Show a popup with the qd notice messages if present
                        PopupNotice(oQueueDump);
                    }
                    catch (Exception oException)
                    {
                        StringBuilder oString = new StringBuilder();
                        oString.Append("Error: Failed to parse the Queue Dump XML file: ");
                        oString.Append(txtQueueDumpFile.Text);
                        oString.Append("\r\n");
                        oString.Append("\r\nError Message:\r\n");
                        oString.Append(oException.Message);

                        MessageBox.Show(oString.ToString(), "Error");
                    }
                }
            }
        }

        private void btnLoadXML_Click(object sender, EventArgs e)
        {
            //////////////////////////////////////////////
            // Create object to be constructed from the XML file content
            QueueDump oQueueDump = new QueueDump();

            try
            {
                this.Cursor = Cursors.WaitCursor;
                oQueueDump = XmlQueueDump.ParseXmlFile(txtQueueDumpFile.Text, oQueueDump);
                if (!String.IsNullOrEmpty(oQueueDump.Error))
                {
                    throw new Exception(oQueueDump.Error);
                }

                // set the controls to the values from the QueueDump object
                SetControls(oQueueDump);

                this.Cursor = Cursors.Default;

                // Show a popup with the qd notice messages if present
                PopupNotice(oQueueDump);
            }
            catch (Exception oException)
            {
                StringBuilder oString = new StringBuilder();
                oString.Append("Error: Failed to parse the Queue Dump XML file: ");
                oString.Append(txtQueueDumpFile.Text);
                oString.Append("\r\n");
                oString.Append("\r\nError Message:\r\n");
                oString.Append(oException.Message);

                MessageBox.Show(oString.ToString(), "Error");
            }
        }

        private void btnFahDirectoryBrowse_Click(object sender, EventArgs e)
        {
            FolderBrowserDialog oFolderBrowserDialog = new FolderBrowserDialog();
            oFolderBrowserDialog.ShowNewFolderButton = false;

            if (!String.IsNullOrEmpty(txtFahDirectory.Text))
            {
                oFolderBrowserDialog.SelectedPath = txtFahDirectory.Text;
            }


            if (oFolderBrowserDialog.ShowDialog() != DialogResult.Cancel)
            {
                txtFahDirectory.Text = oFolderBrowserDialog.SelectedPath;
            }
        }

        private void btnQueueDumpBrowse_Click(object sender, EventArgs e)
        {
            openFileDialogQueueDumpFile.Title = "Select a File";
            openFileDialogQueueDumpFile.InitialDirectory = @"C:\";
            openFileDialogQueueDumpFile.Filter = "All Files|*.*";
            openFileDialogQueueDumpFile.CheckFileExists = false;
            openFileDialogQueueDumpFile.FileName = "qd-output.xml";

            if (!String.IsNullOrEmpty(txtQueueDumpFile.Text))
            {
                int iLastIndex = txtQueueDumpFile.Text.LastIndexOf("\\");
                int iLength = txtQueueDumpFile.Text.Length - (txtQueueDumpFile.Text.Length - iLastIndex);

                string sDirectory = txtQueueDumpFile.Text.Substring(0, iLength);
                string sFilename = txtQueueDumpFile.Text.Substring(iLastIndex + 1);

                openFileDialogQueueDumpFile.InitialDirectory = sDirectory;
                openFileDialogQueueDumpFile.FileName = sFilename;
            }

            if (openFileDialogQueueDumpFile.ShowDialog() != DialogResult.Cancel)
            {
                txtQueueDumpFile.Text = openFileDialogQueueDumpFile.FileName;
            }
        }

        private void SetControls(QueueDump voQueueDump)
        {
            // Reset the controls to their default heights
            SetDefaultHeights();

            //////////////////////////////////////////////
            // Set the controls on all the tabs to the values in the qd XML file

            #region QD Information

            // Queue Dump - Program Information
            //
            // qd
            // <date>7 February 2008</date>
            if (!String.IsNullOrEmpty(voQueueDump.QD.Date))
            {
                lblQDVersionValue.Text = voQueueDump.QD.Date;
            }
            else
            {
                lblQDVersionValue.Text = "n/a";
            }
            // <functional_revision>063</functional_revision>
            if (!String.IsNullOrEmpty(voQueueDump.QD.FunctionalRevision))
            {
                lblQDFunctionalRevisionValue.Text = voQueueDump.QD.FunctionalRevision;
            }
            else
            {
                lblQDFunctionalRevisionValue.Text = "n/a";
            }


            // qdinfo.dat
            // <qdinfo>7 February 2008 (update-qd.pl)</qdinfo>
            if (!String.IsNullOrEmpty(voQueueDump.QDInfo.Date))
            {
                StringBuilder oString = new StringBuilder(voQueueDump.QDInfo.Date);
                if (!String.IsNullOrEmpty(voQueueDump.QDInfo.MaintainedBy))
                {
                    oString.AppendFormat(" ({0})", voQueueDump.QDInfo.MaintainedBy);
                }

                lblQDInfoVersionValue.Text = oString.ToString();
            }
	        else 
	        {
    		    lblQDInfoVersionValue.Text = "n/a";
	        }
            if (!String.IsNullOrEmpty(voQueueDump.QDInfo.FunctionalRevision))
            {
                lblQDInfoFunctionalRevisionAvailableValue.Text = voQueueDump.QDInfo.FunctionalRevision;

                lblQDInfoFunctionalRevisionAvailableText.Visible = true;
                lblQDInfoFunctionalRevisionAvailableCollon.Visible = true;
                lblQDInfoFunctionalRevisionAvailableValue.Visible = true;
            }
            else
            {
                lblQDInfoFunctionalRevisionAvailableValue.Text = "n/a";

                lblQDInfoFunctionalRevisionAvailableText.Visible = false;
                lblQDInfoFunctionalRevisionAvailableCollon.Visible = false;
                lblQDInfoFunctionalRevisionAvailableValue.Visible = false;
            }

            #endregion QD Information

            #region Queue Prefix

            // Queue Dump - Queue
            //
            // Queue container

	        // <version>5.01</version>
            if (!String.IsNullOrEmpty(voQueueDump.Queue.Version))
            {
                lblQueueVersionValue.Text = voQueueDump.Queue.Version;
            }
	        else 
	        {
                lblQueueVersionValue.Text = "n/a";
	        }

	        // <system_type>Linux</system_type>
            if (!String.IsNullOrEmpty(voQueueDump.Queue.SystemType))
            {
                lblQueueSystemTypeValue.Text = voQueueDump.Queue.SystemType;
            }
	        else 
	        {
                lblQueueSystemTypeValue.Text = "n/a";
	        }

	        // <current_index>1</current_index>
            if (Convert.ToInt32(voQueueDump.Queue.CurrentIndex) >= 0 && Convert.ToInt32(voQueueDump.Queue.CurrentIndex) <= 9)
            {
                lblQueueCurrentIndexValue.Text = voQueueDump.Queue.CurrentIndex;

                // select the tab for the current index
                int iActiveTab = Convert.ToInt32(voQueueDump.Queue.CurrentIndex);
                tabctrlQueueDump.SelectedIndex = iActiveTab;
            }
	        else 
	        {
		        lblQueueCurrentIndexValue.Text = "n/a";
	        }

            #endregion Queue Prefix

            #region Queue Indices

            // Tabs: Index 0 - Index 9
            // queue indices
	        for (int i = 0; i <= 9; i++)
	        {
                string sStatus = "";

                if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Status))
                {
                    sStatus = voQueueDump.Queue.Index[i].Status;

                    switch (i)
                    {
                        case 0:
                            lblIndex0GeneralStatusValue.Text = voQueueDump.Queue.Index[i].Status;
                            break;
                        case 1:
                            lblIndex1GeneralStatusValue.Text = voQueueDump.Queue.Index[i].Status;
                            break;
                        case 2:
                            lblIndex2GeneralStatusValue.Text = voQueueDump.Queue.Index[i].Status;
                            break;
                        case 3:
                            lblIndex3GeneralStatusValue.Text = voQueueDump.Queue.Index[i].Status;
                            break;
                        case 4:
                            lblIndex4GeneralStatusValue.Text = voQueueDump.Queue.Index[i].Status;
                            break;
                        case 5:
                            lblIndex5GeneralStatusValue.Text = voQueueDump.Queue.Index[i].Status;
                            break;
                        case 6:
                            lblIndex6GeneralStatusValue.Text = voQueueDump.Queue.Index[i].Status;
                            break;
                        case 7:
                            lblIndex7GeneralStatusValue.Text = voQueueDump.Queue.Index[i].Status;
                            break;
                        case 8:
                            lblIndex8GeneralStatusValue.Text = voQueueDump.Queue.Index[i].Status;
                            break;
                        case 9:
                            lblIndex9GeneralStatusValue.Text = voQueueDump.Queue.Index[i].Status;
                            break;
                    }
                }
                else
                {
                    switch (i)
                    {
                        case 0:
                            lblIndex0GeneralStatusValue.Text = "n/a";
                            break;
                        case 1:
                            lblIndex1GeneralStatusValue.Text = "n/a";
                            break;
                        case 2:
                            lblIndex2GeneralStatusValue.Text = "n/a";
                            break;
                        case 3:
                            lblIndex3GeneralStatusValue.Text = "n/a";
                            break;
                        case 4:
                            lblIndex4GeneralStatusValue.Text = "n/a";
                            break;
                        case 5:
                            lblIndex5GeneralStatusValue.Text = "n/a";
                            break;
                        case 6:
                            lblIndex6GeneralStatusValue.Text = "n/a";
                            break;
                        case 7:
                            lblIndex7GeneralStatusValue.Text = "n/a";
                            break;
                        case 8:
                            lblIndex8GeneralStatusValue.Text = "n/a";
                            break;
                        case 9:
                            lblIndex9GeneralStatusValue.Text = "n/a";
                            break;
                    }
                }

                // Hide all the unused queue fields if the index is marked as empty
                if (String.Equals(sStatus, "empty"))
                {
                    #region Hide Unused Controls
                    
                    // Hide all controls except:
                    // - grpbxIndex0General
                    // - lblIndex0GeneralProjectText
                    // - lblIndex0GeneralProjectCollon
                    // - lblIndex0GeneralProjectValue
                    TableLayoutPanel oTableLayoutPanel = new TableLayoutPanel();
                    GroupBox grpbxGeneral = new GroupBox();
                    Control.ControlCollection oControlCollection = new Control.ControlCollection(this.Owner);
                    List<string> oExcludeControls = new List<string>();

                    switch (i)
                    {
                        case 0:
                            oTableLayoutPanel = tlpIndex0;
                            grpbxGeneral = grpbxIndex0General;
                            oExcludeControls.Add("tabpIndex0");
                            oExcludeControls.Add("grpbxIndex0");
                            oExcludeControls.Add("panelIndex0");
                            oExcludeControls.Add("tlpIndex0");
                            oExcludeControls.Add("grpbxIndex0General");
                            oExcludeControls.Add("lblIndex0GeneralStatusText");
                            oExcludeControls.Add("lblIndex0GeneralStatusCollon");
                            oExcludeControls.Add("lblIndex0GeneralStatusValue");
                            break;
                        case 1:
                            oTableLayoutPanel = tlpIndex1;
                            grpbxGeneral = grpbxIndex1General;
                            oExcludeControls.Add("tabpIndex1");
                            oExcludeControls.Add("grpbxIndex1");
                            oExcludeControls.Add("panelIndex1");
                            oExcludeControls.Add("tlpIndex1");
                            oExcludeControls.Add("grpbxIndex1General");
                            oExcludeControls.Add("lblIndex1GeneralStatusText");
                            oExcludeControls.Add("lblIndex1GeneralStatusCollon");
                            oExcludeControls.Add("lblIndex1GeneralStatusValue");
                            break;
                        case 2:
                            oTableLayoutPanel = tlpIndex2;
                            grpbxGeneral = grpbxIndex2General;
                            oExcludeControls.Add("tabpIndex2");
                            oExcludeControls.Add("grpbxIndex2");
                            oExcludeControls.Add("panelIndex2");
                            oExcludeControls.Add("tlpIndex2");
                            oExcludeControls.Add("grpbxIndex2General");
                            oExcludeControls.Add("lblIndex2GeneralStatusText");
                            oExcludeControls.Add("lblIndex2GeneralStatusCollon");
                            oExcludeControls.Add("lblIndex2GeneralStatusValue");
                            break;
                        case 3:
                            oTableLayoutPanel = tlpIndex3;
                            grpbxGeneral = grpbxIndex3General;
                            oExcludeControls.Add("tabpIndex3");
                            oExcludeControls.Add("grpbxIndex3");
                            oExcludeControls.Add("panelIndex3");
                            oExcludeControls.Add("tlpIndex3");
                            oExcludeControls.Add("grpbxIndex3General");
                            oExcludeControls.Add("lblIndex3GeneralStatusText");
                            oExcludeControls.Add("lblIndex3GeneralStatusCollon");
                            oExcludeControls.Add("lblIndex3GeneralStatusValue");
                            break;
                        case 4:
                            oTableLayoutPanel = tlpIndex4;
                            grpbxGeneral = grpbxIndex4General;
                            oExcludeControls.Add("tabpIndex4");
                            oExcludeControls.Add("grpbxIndex4");
                            oExcludeControls.Add("panelIndex4");
                            oExcludeControls.Add("tlpIndex4");
                            oExcludeControls.Add("grpbxIndex4General");
                            oExcludeControls.Add("lblIndex4GeneralStatusText");
                            oExcludeControls.Add("lblIndex4GeneralStatusCollon");
                            oExcludeControls.Add("lblIndex4GeneralStatusValue");
                            break;
                        case 5:
                            oTableLayoutPanel = tlpIndex5;
                            grpbxGeneral = grpbxIndex5General;
                            oExcludeControls.Add("tabpIndex5");
                            oExcludeControls.Add("grpbxIndex5");
                            oExcludeControls.Add("panelIndex5");
                            oExcludeControls.Add("tlpIndex5");
                            oExcludeControls.Add("grpbxIndex5General");
                            oExcludeControls.Add("lblIndex5GeneralStatusText");
                            oExcludeControls.Add("lblIndex5GeneralStatusCollon");
                            oExcludeControls.Add("lblIndex5GeneralStatusValue");
                            break;
                        case 6:
                            oTableLayoutPanel = tlpIndex6;
                            grpbxGeneral = grpbxIndex6General;
                            oExcludeControls.Add("tabpIndex6");
                            oExcludeControls.Add("grpbxIndex6");
                            oExcludeControls.Add("panelIndex6");
                            oExcludeControls.Add("tlpIndex6");
                            oExcludeControls.Add("grpbxIndex6General");
                            oExcludeControls.Add("lblIndex6GeneralStatusText");
                            oExcludeControls.Add("lblIndex6GeneralStatusCollon");
                            oExcludeControls.Add("lblIndex6GeneralStatusValue");
                            break;
                        case 7:
                            oTableLayoutPanel = tlpIndex7;
                            grpbxGeneral = grpbxIndex7General;
                            oExcludeControls.Add("tabpIndex7");
                            oExcludeControls.Add("grpbxIndex7");
                            oExcludeControls.Add("panelIndex7");
                            oExcludeControls.Add("tlpIndex7");
                            oExcludeControls.Add("grpbxIndex7General");
                            oExcludeControls.Add("lblIndex7GeneralStatusText");
                            oExcludeControls.Add("lblIndex7GeneralStatusCollon");
                            oExcludeControls.Add("lblIndex7GeneralStatusValue");
                            break;
                        case 8:
                            oTableLayoutPanel = tlpIndex8;
                            grpbxGeneral = grpbxIndex8General;
                            oExcludeControls.Add("tabpIndex8");
                            oExcludeControls.Add("grpbxIndex8");
                            oExcludeControls.Add("panelIndex8");
                            oExcludeControls.Add("tlpIndex8");
                            oExcludeControls.Add("grpbxIndex8General");
                            oExcludeControls.Add("lblIndex8GeneralStatusText");
                            oExcludeControls.Add("lblIndex8GeneralStatusCollon");
                            oExcludeControls.Add("lblIndex8GeneralStatusValue");
                            break;
                        case 9:
                            oTableLayoutPanel = tlpIndex9;
                            grpbxGeneral = grpbxIndex9General;
                            oExcludeControls.Add("tabpIndex9");
                            oExcludeControls.Add("grpbxIndex9");
                            oExcludeControls.Add("panelIndex9");
                            oExcludeControls.Add("tlpIndex9");
                            oExcludeControls.Add("grpbxIndex9General");
                            oExcludeControls.Add("lblIndex9GeneralStatusText");
                            oExcludeControls.Add("lblIndex9GeneralStatusCollon");
                            oExcludeControls.Add("lblIndex9GeneralStatusValue");
                            break;
                    }

                    // Hide all the unused GroupBoxes in the TableLayoutPanel
                    // And substract the unused Height from the TableLayoutPanel
                    #region Hide Unused GroupBoxes

                    foreach (Control oControl in oTableLayoutPanel.Controls)
                    {
                        bool bExcludeControl = false;
                        foreach (string sExcludeControl in oExcludeControls)
                        {
                            if (oControl.Name.Equals(sExcludeControl)) 
                            {
                                bExcludeControl = true;
                            }
                        }

                        if (bExcludeControl == false) 
                        {
                            oTableLayoutPanel.Height = oTableLayoutPanel.Height - oControl.Height;
                            oControl.Hide();
                        }
                    }

                    #endregion Hide Unused GroupBoxes

                    // Hide all the unused Labels in the grpbxIndexNGeneral
                    // And substract the unused Height from the TableLayoutPanel and grpbxIndexNGeneral
                    #region Hide Unused Labels

                    int iTotalHiddenHeight = 0;
                    foreach (Control oControl in grpbxGeneral.Controls)
                    {
                        bool bExcludeControl = false;
                        foreach (string sExcludeControl in oExcludeControls)
                        {
                            if (oControl.Name.Equals(sExcludeControl))
                            {
                                bExcludeControl = true;
                            }
                        }

                        if (bExcludeControl == false)
                        {
                            if (Regex.IsMatch(oControl.Name, "^lblIndex[0-9]General.*?Text$"))
                            {
                                iTotalHiddenHeight += oControl.Height;
                            }
                            oControl.Hide();
                        }
                    }
                    grpbxGeneral.Height = grpbxGeneral.Height - iTotalHiddenHeight;

                    #endregion Hide Unused Labels

                    #endregion Hide Unused Controls
                }
                else
                {
                    #region Show Used Controls

                    TableLayoutPanel oTableLayoutPanel = new TableLayoutPanel();
                    GroupBox grpbxGeneral = new GroupBox();
                    Control.ControlCollection oControlCollection = new Control.ControlCollection(this.Owner);

                    switch (i)
                    {
                        case 0:
                            oTableLayoutPanel = tlpIndex0;
                            grpbxGeneral = grpbxIndex0General;
                            break;
                        case 1:
                            oTableLayoutPanel = tlpIndex1;
                            grpbxGeneral = grpbxIndex1General;
                            break;
                        case 2:
                            oTableLayoutPanel = tlpIndex2;
                            grpbxGeneral = grpbxIndex2General;
                            break;
                        case 3:
                            oTableLayoutPanel = tlpIndex3;
                            grpbxGeneral = grpbxIndex3General;
                            break;
                        case 4:
                            oTableLayoutPanel = tlpIndex4;
                            grpbxGeneral = grpbxIndex4General;
                            break;
                        case 5:
                            oTableLayoutPanel = tlpIndex5;
                            grpbxGeneral = grpbxIndex5General;
                            break;
                        case 6:
                            oTableLayoutPanel = tlpIndex6;
                            grpbxGeneral = grpbxIndex6General;
                            break;
                        case 7:
                            oTableLayoutPanel = tlpIndex7;
                            grpbxGeneral = grpbxIndex7General;
                            break;
                        case 8:
                            oTableLayoutPanel = tlpIndex8;
                            grpbxGeneral = grpbxIndex8General;
                            break;
                        case 9:
                            oTableLayoutPanel = tlpIndex9;
                            grpbxGeneral = grpbxIndex9General;
                            break;
                    }

                    // Unhide all the unused GroupBoxes in the TableLayoutPanel
                    #region Show Used GroupBoxes

                    foreach (Control oControl in oTableLayoutPanel.Controls)
                    {
                        oControl.Show();
                    }

                    #endregion Show Used GroupBoxes

                    // Unhide all the unused Labels in the grpbxIndexNGeneral
                    #region Show Used Labels

                    foreach (Control oControl in grpbxGeneral.Controls)
                    {
                        oControl.Show();
                    }

                    #endregion Show Used Labels

                    #endregion Show Used Controls
                
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].ProjectNumber))
                    {
                        if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].ProjectName))
                        {
                            StringBuilder oString = new StringBuilder(voQueueDump.Queue.Index[i].ProjectNumber);
                            oString.Append(" \"");
                            oString.Append(voQueueDump.Queue.Index[i].ProjectName);
                            oString.Append("\" ");

                            switch (i)
                            {
                                case 0:
                                    lblIndex0GeneralProjectValue.Text = oString.ToString();
                                    break;
                                case 1:
                                    lblIndex1GeneralProjectValue.Text = oString.ToString();
                                    break;
                                case 2:
                                    lblIndex2GeneralProjectValue.Text = oString.ToString();
                                    break;
                                case 3:
                                    lblIndex3GeneralProjectValue.Text = oString.ToString();
                                    break;
                                case 4:
                                    lblIndex4GeneralProjectValue.Text = oString.ToString();
                                    break;
                                case 5:
                                    lblIndex5GeneralProjectValue.Text = oString.ToString();
                                    break;
                                case 6:
                                    lblIndex6GeneralProjectValue.Text = oString.ToString();
                                    break;
                                case 7:
                                    lblIndex7GeneralProjectValue.Text = oString.ToString();
                                    break;
                                case 8:
                                    lblIndex8GeneralProjectValue.Text = oString.ToString();
                                    break;
                                case 9:
                                    lblIndex9GeneralProjectValue.Text = oString.ToString();
                                    break;
                            }
                        }
                        else
                        {
                            switch (i)
                            {
                                case 0:
                                    lblIndex0GeneralProjectValue.Text = voQueueDump.Queue.Index[i].ProjectNumber;
                                    break;
                                case 1:
                                    lblIndex1GeneralProjectValue.Text = voQueueDump.Queue.Index[i].ProjectNumber;
                                    break;
                                case 2:
                                    lblIndex2GeneralProjectValue.Text = voQueueDump.Queue.Index[i].ProjectNumber;
                                    break;
                                case 3:
                                    lblIndex3GeneralProjectValue.Text = voQueueDump.Queue.Index[i].ProjectNumber;
                                    break;
                                case 4:
                                    lblIndex4GeneralProjectValue.Text = voQueueDump.Queue.Index[i].ProjectNumber;
                                    break;
                                case 5:
                                    lblIndex5GeneralProjectValue.Text = voQueueDump.Queue.Index[i].ProjectNumber;
                                    break;
                                case 6:
                                    lblIndex6GeneralProjectValue.Text = voQueueDump.Queue.Index[i].ProjectNumber;
                                    break;
                                case 7:
                                    lblIndex7GeneralProjectValue.Text = voQueueDump.Queue.Index[i].ProjectNumber;
                                    break;
                                case 8:
                                    lblIndex8GeneralProjectValue.Text = voQueueDump.Queue.Index[i].ProjectNumber;
                                    break;
                                case 9:
                                    lblIndex9GeneralProjectValue.Text = voQueueDump.Queue.Index[i].ProjectNumber;
                                    break;
                            }
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0GeneralProjectValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1GeneralProjectValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2GeneralProjectValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3GeneralProjectValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4GeneralProjectValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5GeneralProjectValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6GeneralProjectValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7GeneralProjectValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8GeneralProjectValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9GeneralProjectValue.Text = "n/a";
                                break;
                        }
                    }
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Points))
                    {
                        if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].PointsPerHour))
                        {
                            StringBuilder oString = new StringBuilder(voQueueDump.Queue.Index[i].Points);
                            oString.Append(" (");
                            oString.Append(voQueueDump.Queue.Index[i].PointsPerHour);
                            oString.Append(" points/hour)");

                            switch (i)
                            {
                                case 0:
                                    lblIndex0GeneralPointsValue.Text = oString.ToString();
                                    break;
                                case 1:
                                    lblIndex1GeneralPointsValue.Text = oString.ToString();
                                    break;
                                case 2:
                                    lblIndex2GeneralPointsValue.Text = oString.ToString();
                                    break;
                                case 3:
                                    lblIndex3GeneralPointsValue.Text = oString.ToString();
                                    break;
                                case 4:
                                    lblIndex4GeneralPointsValue.Text = oString.ToString();
                                    break;
                                case 5:
                                    lblIndex5GeneralPointsValue.Text = oString.ToString();
                                    break;
                                case 6:
                                    lblIndex6GeneralPointsValue.Text = oString.ToString();
                                    break;
                                case 7:
                                    lblIndex7GeneralPointsValue.Text = oString.ToString();
                                    break;
                                case 8:
                                    lblIndex8GeneralPointsValue.Text = oString.ToString();
                                    break;
                                case 9:
                                    lblIndex9GeneralPointsValue.Text = oString.ToString();
                                    break;
                            }
                        }
                        else
                        {
                            switch (i)
                            {
                                case 0:
                                    lblIndex0GeneralPointsValue.Text = voQueueDump.Queue.Index[i].Points;
                                    break;
                                case 1:
                                    lblIndex1GeneralPointsValue.Text = voQueueDump.Queue.Index[i].Points;
                                    break;
                                case 2:
                                    lblIndex2GeneralPointsValue.Text = voQueueDump.Queue.Index[i].Points;
                                    break;
                                case 3:
                                    lblIndex3GeneralPointsValue.Text = voQueueDump.Queue.Index[i].Points;
                                    break;
                                case 4:
                                    lblIndex4GeneralPointsValue.Text = voQueueDump.Queue.Index[i].Points;
                                    break;
                                case 5:
                                    lblIndex5GeneralPointsValue.Text = voQueueDump.Queue.Index[i].Points;
                                    break;
                                case 6:
                                    lblIndex6GeneralPointsValue.Text = voQueueDump.Queue.Index[i].Points;
                                    break;
                                case 7:
                                    lblIndex7GeneralPointsValue.Text = voQueueDump.Queue.Index[i].Points;
                                    break;
                                case 8:
                                    lblIndex8GeneralPointsValue.Text = voQueueDump.Queue.Index[i].Points;
                                    break;
                                case 9:
                                    lblIndex9GeneralPointsValue.Text = voQueueDump.Queue.Index[i].Points;
                                    break;
                            }
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0GeneralPointsValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1GeneralPointsValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2GeneralPointsValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3GeneralPointsValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4GeneralPointsValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5GeneralPointsValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6GeneralPointsValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7GeneralPointsValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8GeneralPointsValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9GeneralPointsValue.Text = "n/a";
                                break;
                        }
                    }
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Progress))
                    {
                        if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].ProgressRate))
                        {
                            StringBuilder oString = new StringBuilder(voQueueDump.Queue.Index[i].Progress);
                            oString.Append(" (");
                            oString.Append(voQueueDump.Queue.Index[i].ProgressRate);
                            oString.Append(" X min speed)");

                            switch (i)
                            {
                                case 0:
                                    lblIndex0GeneralProgressValue.Text = oString.ToString();
                                    break;
                                case 1:
                                    lblIndex1GeneralProgressValue.Text = oString.ToString();
                                    break;
                                case 2:
                                    lblIndex2GeneralProgressValue.Text = oString.ToString();
                                    break;
                                case 3:
                                    lblIndex3GeneralProgressValue.Text = oString.ToString();
                                    break;
                                case 4:
                                    lblIndex4GeneralProgressValue.Text = oString.ToString();
                                    break;
                                case 5:
                                    lblIndex5GeneralProgressValue.Text = oString.ToString();
                                    break;
                                case 6:
                                    lblIndex6GeneralProgressValue.Text = oString.ToString();
                                    break;
                                case 7:
                                    lblIndex7GeneralProgressValue.Text = oString.ToString();
                                    break;
                                case 8:
                                    lblIndex8GeneralProgressValue.Text = oString.ToString();
                                    break;
                                case 9:
                                    lblIndex9GeneralProgressValue.Text = oString.ToString();
                                    break;
                            }
                        }
                        else
                        {
                            switch (i)
                            {
                                case 0:
                                    lblIndex0GeneralProgressValue.Text = voQueueDump.Queue.Index[i].Progress;
                                    break;
                                case 1:
                                    lblIndex1GeneralProgressValue.Text = voQueueDump.Queue.Index[i].Progress;
                                    break;
                                case 2:
                                    lblIndex2GeneralProgressValue.Text = voQueueDump.Queue.Index[i].Progress;
                                    break;
                                case 3:
                                    lblIndex3GeneralProgressValue.Text = voQueueDump.Queue.Index[i].Progress;
                                    break;
                                case 4:
                                    lblIndex4GeneralProgressValue.Text = voQueueDump.Queue.Index[i].Progress;
                                    break;
                                case 5:
                                    lblIndex5GeneralProgressValue.Text = voQueueDump.Queue.Index[i].Progress;
                                    break;
                                case 6:
                                    lblIndex6GeneralProgressValue.Text = voQueueDump.Queue.Index[i].Progress;
                                    break;
                                case 7:
                                    lblIndex7GeneralProgressValue.Text = voQueueDump.Queue.Index[i].Progress;
                                    break;
                                case 8:
                                    lblIndex8GeneralProgressValue.Text = voQueueDump.Queue.Index[i].Progress;
                                    break;
                                case 9:
                                    lblIndex9GeneralProgressValue.Text = voQueueDump.Queue.Index[i].Progress;
                                    break;
                            }
                        }
                    }
                    else if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].ProgressRate))
                    {
                        StringBuilder oString = new StringBuilder(voQueueDump.Queue.Index[i].ProgressRate);
                        oString.Append(" X min speed");

                        switch (i)
                        {
                            case 0:
                                lblIndex0GeneralProgressValue.Text = oString.ToString();
                                break;
                            case 1:
                                lblIndex1GeneralProgressValue.Text = oString.ToString();
                                break;
                            case 2:
                                lblIndex2GeneralProgressValue.Text = oString.ToString();
                                break;
                            case 3:
                                lblIndex3GeneralProgressValue.Text = oString.ToString();
                                break;
                            case 4:
                                lblIndex4GeneralProgressValue.Text = oString.ToString();
                                break;
                            case 5:
                                lblIndex5GeneralProgressValue.Text = oString.ToString();
                                break;
                            case 6:
                                lblIndex6GeneralProgressValue.Text = oString.ToString();
                                break;
                            case 7:
                                lblIndex7GeneralProgressValue.Text = oString.ToString();
                                break;
                            case 8:
                                lblIndex8GeneralProgressValue.Text = oString.ToString();
                                break;
                            case 9:
                                lblIndex9GeneralProgressValue.Text = oString.ToString();
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0GeneralProgressValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1GeneralProgressValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2GeneralProgressValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3GeneralProgressValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4GeneralProgressValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5GeneralProgressValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6GeneralProgressValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7GeneralProgressValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8GeneralProgressValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9GeneralProgressValue.Text = "n/a";
                                break;
                        }
                    }

                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Server[0].Number))
                    {
                        switch (voQueueDump.Queue.Index[i].Server[0].Number)
                        {
                            case "1":
                                switch (i)
                                {
                                    case 0:
                                        lblIndex0GeneralServer1Value.Text = voQueueDump.Queue.Index[i].Server[0].Address;
                                        break;
                                    case 1:
                                        lblIndex1GeneralServer1Value.Text = voQueueDump.Queue.Index[i].Server[0].Address;
                                        break;
                                    case 2:
                                        lblIndex2GeneralServer1Value.Text = voQueueDump.Queue.Index[i].Server[0].Address;
                                        break;
                                    case 3:
                                        lblIndex3GeneralServer1Value.Text = voQueueDump.Queue.Index[i].Server[0].Address;
                                        break;
                                    case 4:
                                        lblIndex4GeneralServer1Value.Text = voQueueDump.Queue.Index[i].Server[0].Address;
                                        break;
                                    case 5:
                                        lblIndex5GeneralServer1Value.Text = voQueueDump.Queue.Index[i].Server[0].Address;
                                        break;
                                    case 6:
                                        lblIndex6GeneralServer1Value.Text = voQueueDump.Queue.Index[i].Server[0].Address;
                                        break;
                                    case 7:
                                        lblIndex7GeneralServer1Value.Text = voQueueDump.Queue.Index[i].Server[0].Address;
                                        break;
                                    case 8:
                                        lblIndex8GeneralServer1Value.Text = voQueueDump.Queue.Index[i].Server[0].Address;
                                        break;
                                    case 9:
                                        lblIndex9GeneralServer1Value.Text = voQueueDump.Queue.Index[i].Server[0].Address;
                                        break;
                                }
                                break;
                            case "2":
                                switch (i)
                                {
                                    case 0:
                                        lblIndex0GeneralServer2Value.Text = voQueueDump.Queue.Index[i].Server[0].Address;
                                        break;
                                    case 1:
                                        lblIndex1GeneralServer2Value.Text = voQueueDump.Queue.Index[i].Server[0].Address;
                                        break;
                                    case 2:
                                        lblIndex2GeneralServer2Value.Text = voQueueDump.Queue.Index[i].Server[0].Address;
                                        break;
                                    case 3:
                                        lblIndex3GeneralServer2Value.Text = voQueueDump.Queue.Index[i].Server[0].Address;
                                        break;
                                    case 4:
                                        lblIndex4GeneralServer2Value.Text = voQueueDump.Queue.Index[i].Server[0].Address;
                                        break;
                                    case 5:
                                        lblIndex5GeneralServer2Value.Text = voQueueDump.Queue.Index[i].Server[0].Address;
                                        break;
                                    case 6:
                                        lblIndex6GeneralServer2Value.Text = voQueueDump.Queue.Index[i].Server[0].Address;
                                        break;
                                    case 7:
                                        lblIndex7GeneralServer2Value.Text = voQueueDump.Queue.Index[i].Server[0].Address;
                                        break;
                                    case 8:
                                        lblIndex8GeneralServer2Value.Text = voQueueDump.Queue.Index[i].Server[0].Address;
                                        break;
                                    case 9:
                                        lblIndex9GeneralServer2Value.Text = voQueueDump.Queue.Index[i].Server[0].Address;
                                        break;
                                }
                                break;
                        }
                    }
                    else
                    {
                        switch (voQueueDump.Queue.Index[i].Server[0].Number)
                        {
                            case "1":
                                switch (i)
                                {
                                    case 0:
                                        lblIndex0GeneralServer1Value.Text = "n/a";
                                        break;
                                    case 1:
                                        lblIndex1GeneralServer1Value.Text = "n/a";
                                        break;
                                    case 2:
                                        lblIndex2GeneralServer1Value.Text = "n/a";
                                        break;
                                    case 3:
                                        lblIndex3GeneralServer1Value.Text = "n/a";
                                        break;
                                    case 4:
                                        lblIndex4GeneralServer1Value.Text = "n/a";
                                        break;
                                    case 5:
                                        lblIndex5GeneralServer1Value.Text = "n/a";
                                        break;
                                    case 6:
                                        lblIndex6GeneralServer1Value.Text = "n/a";
                                        break;
                                    case 7:
                                        lblIndex7GeneralServer1Value.Text = "n/a";
                                        break;
                                    case 8:
                                        lblIndex8GeneralServer1Value.Text = "n/a";
                                        break;
                                    case 9:
                                        lblIndex9GeneralServer1Value.Text = "n/a";
                                        break;
                                }
                                break;
                            case "2":
                                switch (i)
                                {
                                    case 0:
                                        lblIndex0GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 1:
                                        lblIndex1GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 2:
                                        lblIndex2GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 3:
                                        lblIndex3GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 4:
                                        lblIndex4GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 5:
                                        lblIndex5GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 6:
                                        lblIndex6GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 7:
                                        lblIndex7GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 8:
                                        lblIndex8GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 9:
                                        lblIndex9GeneralServer2Value.Text = "n/a";
                                        break;
                                }
                                break;
                            case "":
                                switch (i)
                                {
                                    case 0:
                                        lblIndex0GeneralServer1Value.Text = "n/a";
                                        lblIndex0GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 1:
                                        lblIndex1GeneralServer1Value.Text = "n/a";
                                        lblIndex1GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 2:
                                        lblIndex2GeneralServer1Value.Text = "n/a";
                                        lblIndex2GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 3:
                                        lblIndex3GeneralServer1Value.Text = "n/a";
                                        lblIndex3GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 4:
                                        lblIndex4GeneralServer1Value.Text = "n/a";
                                        lblIndex4GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 5:
                                        lblIndex5GeneralServer1Value.Text = "n/a";
                                        lblIndex5GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 6:
                                        lblIndex6GeneralServer1Value.Text = "n/a";
                                        lblIndex6GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 7:
                                        lblIndex7GeneralServer1Value.Text = "n/a";
                                        lblIndex7GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 8:
                                        lblIndex8GeneralServer1Value.Text = "n/a";
                                        lblIndex8GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 9:
                                        lblIndex9GeneralServer1Value.Text = "n/a";
                                        lblIndex9GeneralServer2Value.Text = "n/a";
                                        break;
                                }
                                break;
                        }
                    }
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Server[1].Number))
                    {
                        switch (voQueueDump.Queue.Index[i].Server[1].Number)
                        {
                            case "1":
                                switch (i)
                                {
                                    case 0:
                                        lblIndex0GeneralServer1Value.Text = voQueueDump.Queue.Index[i].Server[1].Address;
                                        break;
                                    case 1:
                                        lblIndex1GeneralServer1Value.Text = voQueueDump.Queue.Index[i].Server[1].Address;
                                        break;
                                    case 2:
                                        lblIndex2GeneralServer1Value.Text = voQueueDump.Queue.Index[i].Server[1].Address;
                                        break;
                                    case 3:
                                        lblIndex3GeneralServer1Value.Text = voQueueDump.Queue.Index[i].Server[1].Address;
                                        break;
                                    case 4:
                                        lblIndex4GeneralServer1Value.Text = voQueueDump.Queue.Index[i].Server[1].Address;
                                        break;
                                    case 5:
                                        lblIndex5GeneralServer1Value.Text = voQueueDump.Queue.Index[i].Server[1].Address;
                                        break;
                                    case 6:
                                        lblIndex6GeneralServer1Value.Text = voQueueDump.Queue.Index[i].Server[1].Address;
                                        break;
                                    case 7:
                                        lblIndex7GeneralServer1Value.Text = voQueueDump.Queue.Index[i].Server[1].Address;
                                        break;
                                    case 8:
                                        lblIndex8GeneralServer1Value.Text = voQueueDump.Queue.Index[i].Server[1].Address;
                                        break;
                                    case 9:
                                        lblIndex9GeneralServer1Value.Text = voQueueDump.Queue.Index[i].Server[1].Address;
                                        break;
                                }
                                break;
                            case "2":
                                switch (i)
                                {
                                    case 0:
                                        lblIndex0GeneralServer2Value.Text = voQueueDump.Queue.Index[i].Server[1].Address;
                                        break;
                                    case 1:
                                        lblIndex1GeneralServer2Value.Text = voQueueDump.Queue.Index[i].Server[1].Address;
                                        break;
                                    case 2:
                                        lblIndex2GeneralServer2Value.Text = voQueueDump.Queue.Index[i].Server[1].Address;
                                        break;
                                    case 3:
                                        lblIndex3GeneralServer2Value.Text = voQueueDump.Queue.Index[i].Server[1].Address;
                                        break;
                                    case 4:
                                        lblIndex4GeneralServer2Value.Text = voQueueDump.Queue.Index[i].Server[1].Address;
                                        break;
                                    case 5:
                                        lblIndex5GeneralServer2Value.Text = voQueueDump.Queue.Index[i].Server[1].Address;
                                        break;
                                    case 6:
                                        lblIndex6GeneralServer2Value.Text = voQueueDump.Queue.Index[i].Server[1].Address;
                                        break;
                                    case 7:
                                        lblIndex7GeneralServer2Value.Text = voQueueDump.Queue.Index[i].Server[1].Address;
                                        break;
                                    case 8:
                                        lblIndex8GeneralServer2Value.Text = voQueueDump.Queue.Index[i].Server[1].Address;
                                        break;
                                    case 9:
                                        lblIndex9GeneralServer2Value.Text = voQueueDump.Queue.Index[i].Server[1].Address;
                                        break;
                                }
                                break;
                        }
                    }
                    else
                    {
                        switch (voQueueDump.Queue.Index[i].Server[0].Number)
                        {
                            case "1":
                                switch (i)
                                {
                                    case 0:
                                        lblIndex0GeneralServer1Value.Text = "n/a";
                                        break;
                                    case 1:
                                        lblIndex1GeneralServer1Value.Text = "n/a";
                                        break;
                                    case 2:
                                        lblIndex2GeneralServer1Value.Text = "n/a";
                                        break;
                                    case 3:
                                        lblIndex3GeneralServer1Value.Text = "n/a";
                                        break;
                                    case 4:
                                        lblIndex4GeneralServer1Value.Text = "n/a";
                                        break;
                                    case 5:
                                        lblIndex5GeneralServer1Value.Text = "n/a";
                                        break;
                                    case 6:
                                        lblIndex6GeneralServer1Value.Text = "n/a";
                                        break;
                                    case 7:
                                        lblIndex7GeneralServer1Value.Text = "n/a";
                                        break;
                                    case 8:
                                        lblIndex8GeneralServer1Value.Text = "n/a";
                                        break;
                                    case 9:
                                        lblIndex9GeneralServer1Value.Text = "n/a";
                                        break;
                                }
                                break;
                            case "2":
                                switch (i)
                                {
                                    case 0:
                                        lblIndex0GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 1:
                                        lblIndex1GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 2:
                                        lblIndex2GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 3:
                                        lblIndex3GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 4:
                                        lblIndex4GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 5:
                                        lblIndex5GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 6:
                                        lblIndex6GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 7:
                                        lblIndex7GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 8:
                                        lblIndex8GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 9:
                                        lblIndex9GeneralServer2Value.Text = "n/a";
                                        break;
                                }
                                break;
                            case "":
                                switch (i)
                                {
                                    case 0:
                                        lblIndex0GeneralServer1Value.Text = "n/a";
                                        lblIndex0GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 1:
                                        lblIndex1GeneralServer1Value.Text = "n/a";
                                        lblIndex1GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 2:
                                        lblIndex2GeneralServer1Value.Text = "n/a";
                                        lblIndex2GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 3:
                                        lblIndex3GeneralServer1Value.Text = "n/a";
                                        lblIndex3GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 4:
                                        lblIndex4GeneralServer1Value.Text = "n/a";
                                        lblIndex4GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 5:
                                        lblIndex5GeneralServer1Value.Text = "n/a";
                                        lblIndex5GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 6:
                                        lblIndex6GeneralServer1Value.Text = "n/a";
                                        lblIndex6GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 7:
                                        lblIndex7GeneralServer1Value.Text = "n/a";
                                        lblIndex7GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 8:
                                        lblIndex8GeneralServer1Value.Text = "n/a";
                                        lblIndex8GeneralServer2Value.Text = "n/a";
                                        break;
                                    case 9:
                                        lblIndex9GeneralServer1Value.Text = "n/a";
                                        lblIndex9GeneralServer2Value.Text = "n/a";
                                        break;
                                }
                                break;
                        }
                    }

                    // tag: P2146R0C442F49
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Tag))
                    {
                        Label oLabel = new Label();
                        List<Label> oLabelList = new List<Label>();

                        switch (i)
                        {
                            case 0:
                                oLabel = lblIndex0GeneralTagValue;
                                oLabelList.Add(lblIndex0GeneralTagText);
                                oLabelList.Add(lblIndex0GeneralTagCollon);
                                oLabelList.Add(lblIndex0GeneralTagValue);
                                break;
                            case 1:
                                oLabel = lblIndex1GeneralTagValue;
                                oLabelList.Add(lblIndex1GeneralTagText);
                                oLabelList.Add(lblIndex1GeneralTagCollon);
                                oLabelList.Add(lblIndex1GeneralTagValue);
                                break;
                            case 2:
                                oLabel = lblIndex2GeneralTagValue;
                                oLabelList.Add(lblIndex2GeneralTagText);
                                oLabelList.Add(lblIndex2GeneralTagCollon);
                                oLabelList.Add(lblIndex2GeneralTagValue);
                                break;
                            case 3:
                                oLabel = lblIndex3GeneralTagValue;
                                oLabelList.Add(lblIndex3GeneralTagText);
                                oLabelList.Add(lblIndex3GeneralTagCollon);
                                oLabelList.Add(lblIndex3GeneralTagValue);
                                break;
                            case 4:
                                oLabel = lblIndex4GeneralTagValue;
                                oLabelList.Add(lblIndex4GeneralTagText);
                                oLabelList.Add(lblIndex4GeneralTagCollon);
                                oLabelList.Add(lblIndex4GeneralTagValue);
                                break;
                            case 5:
                                oLabel = lblIndex5GeneralTagValue;
                                oLabelList.Add(lblIndex5GeneralTagText);
                                oLabelList.Add(lblIndex5GeneralTagCollon);
                                oLabelList.Add(lblIndex5GeneralTagValue);
                                break;
                            case 6:
                                oLabel = lblIndex6GeneralTagValue;
                                oLabelList.Add(lblIndex6GeneralTagText);
                                oLabelList.Add(lblIndex6GeneralTagCollon);
                                oLabelList.Add(lblIndex6GeneralTagValue);
                                break;
                            case 7:
                                oLabel = lblIndex7GeneralTagValue;
                                oLabelList.Add(lblIndex7GeneralTagText);
                                oLabelList.Add(lblIndex7GeneralTagCollon);
                                oLabelList.Add(lblIndex7GeneralTagValue);
                                break;
                            case 8:
                                oLabel = lblIndex8GeneralTagValue;
                                oLabelList.Add(lblIndex8GeneralTagText);
                                oLabelList.Add(lblIndex8GeneralTagCollon);
                                oLabelList.Add(lblIndex8GeneralTagValue);
                                break;
                            case 9:
                                oLabel = lblIndex9GeneralTagValue;
                                oLabelList.Add(lblIndex9GeneralTagText);
                                oLabelList.Add(lblIndex9GeneralTagCollon);
                                oLabelList.Add(lblIndex9GeneralTagValue);
                                break;
                        }

                        // Set the label text & show it and its related controls
                        oLabel.Text = voQueueDump.Queue.Index[i].Tag;
                        for (int j = 0; j < oLabelList.Count; j++)
                        {
                            oLabelList[j].Show();
                        }
                    }
                    else
                    {
                        GroupBox oGroupBox = new GroupBox();
                        Label oLabel = new Label();
                        List<Label> oLabelList = new List<Label>();

                        switch (i)
                        {
                            case 0:
                                oTableLayoutPanel = tlpIndex0;
                                oGroupBox = grpbxIndex0General;
                                oLabel = lblIndex0GeneralTagValue;
                                oLabelList.Add(lblIndex0GeneralTagText);
                                oLabelList.Add(lblIndex0GeneralTagCollon);
                                oLabelList.Add(lblIndex0GeneralTagValue);
                                break;
                            case 1:
                                oTableLayoutPanel = tlpIndex1;
                                oGroupBox = grpbxIndex1General;
                                oLabel = lblIndex1GeneralTagValue;
                                oLabelList.Add(lblIndex1GeneralTagText);
                                oLabelList.Add(lblIndex1GeneralTagCollon);
                                oLabelList.Add(lblIndex1GeneralTagValue);
                                break;
                            case 2:
                                oTableLayoutPanel = tlpIndex2;
                                oGroupBox = grpbxIndex2General;
                                oLabel = lblIndex2GeneralTagValue;
                                oLabelList.Add(lblIndex2GeneralTagText);
                                oLabelList.Add(lblIndex2GeneralTagCollon);
                                oLabelList.Add(lblIndex2GeneralTagValue);
                                break;
                            case 3:
                                oTableLayoutPanel = tlpIndex3;
                                oGroupBox = grpbxIndex3General;
                                oLabel = lblIndex3GeneralTagValue;
                                oLabelList.Add(lblIndex3GeneralTagText);
                                oLabelList.Add(lblIndex3GeneralTagCollon);
                                oLabelList.Add(lblIndex3GeneralTagValue);
                                break;
                            case 4:
                                oTableLayoutPanel = tlpIndex4;
                                oGroupBox = grpbxIndex4General;
                                oLabel = lblIndex4GeneralTagValue;
                                oLabelList.Add(lblIndex4GeneralTagText);
                                oLabelList.Add(lblIndex4GeneralTagCollon);
                                oLabelList.Add(lblIndex4GeneralTagValue);
                                break;
                            case 5:
                                oTableLayoutPanel = tlpIndex5;
                                oGroupBox = grpbxIndex5General;
                                oLabel = lblIndex5GeneralTagValue;
                                oLabelList.Add(lblIndex5GeneralTagText);
                                oLabelList.Add(lblIndex5GeneralTagCollon);
                                oLabelList.Add(lblIndex5GeneralTagValue);
                                break;
                            case 6:
                                oTableLayoutPanel = tlpIndex6;
                                oGroupBox = grpbxIndex6General;
                                oLabel = lblIndex6GeneralTagValue;
                                oLabelList.Add(lblIndex6GeneralTagText);
                                oLabelList.Add(lblIndex6GeneralTagCollon);
                                oLabelList.Add(lblIndex6GeneralTagValue);
                                break;
                            case 7:
                                oTableLayoutPanel = tlpIndex7;
                                oGroupBox = grpbxIndex7General;
                                oLabel = lblIndex7GeneralTagValue;
                                oLabelList.Add(lblIndex7GeneralTagText);
                                oLabelList.Add(lblIndex7GeneralTagCollon);
                                oLabelList.Add(lblIndex7GeneralTagValue);
                                break;
                            case 8:
                                oTableLayoutPanel = tlpIndex8;
                                oGroupBox = grpbxIndex8General;
                                oLabel = lblIndex8GeneralTagValue;
                                oLabelList.Add(lblIndex8GeneralTagText);
                                oLabelList.Add(lblIndex8GeneralTagCollon);
                                oLabelList.Add(lblIndex8GeneralTagValue);
                                break;
                            case 9:
                                oTableLayoutPanel = tlpIndex9;
                                oGroupBox = grpbxIndex9General;
                                oLabel = lblIndex9GeneralTagValue;
                                oLabelList.Add(lblIndex9GeneralTagText);
                                oLabelList.Add(lblIndex9GeneralTagCollon);
                                oLabelList.Add(lblIndex9GeneralTagValue);
                                break;
                        }

                        // Reset the label text & hide it and its related controls
                        oLabel.Text = "n/a";
                        for (int j = 0; j < oLabelList.Count; j++)
                        {
                            oLabelList[j].Hide();

                            if (Regex.IsMatch(oLabelList[j].Name, "^lblIndex[0-9]General.*?Text$"))
                            {
                                oGroupBox.Height = oGroupBox.Height - oLabelList[j].Height;
                                oTableLayoutPanel.Height = oTableLayoutPanel.Height - oLabelList[j].Height;
                            }
                        }
                    }

                    // Folding: run 1, clone 19, generation 4; benchmark 797; misc: 500, 300
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Folding.Run)
                       || !String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Folding.Clone)
                       || !String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Folding.Generation)
                       )
                    {
                        StringBuilder oString = new StringBuilder();
                        oString.AppendFormat("Run: {0}, ", voQueueDump.Queue.Index[i].Folding.Run);
                        oString.AppendFormat("Clone: {0}, ", voQueueDump.Queue.Index[i].Folding.Clone);
                        oString.AppendFormat("Generation: {0}", voQueueDump.Queue.Index[i].Folding.Generation);

                        switch (i)
                        {
                            case 0:
                                lblIndex0FoldingTrajectoryValue.Text = oString.ToString();
                                break;
                            case 1:
                                lblIndex1FoldingTrajectoryValue.Text = oString.ToString();
                                break;
                            case 2:
                                lblIndex2FoldingTrajectoryValue.Text = oString.ToString();
                                break;
                            case 3:
                                lblIndex3FoldingTrajectoryValue.Text = oString.ToString();
                                break;
                            case 4:
                                lblIndex4FoldingTrajectoryValue.Text = oString.ToString();
                                break;
                            case 5:
                                lblIndex5FoldingTrajectoryValue.Text = oString.ToString();
                                break;
                            case 6:
                                lblIndex6FoldingTrajectoryValue.Text = oString.ToString();
                                break;
                            case 7:
                                lblIndex7FoldingTrajectoryValue.Text = oString.ToString();
                                break;
                            case 8:
                                lblIndex8FoldingTrajectoryValue.Text = oString.ToString();
                                break;
                            case 9:
                                lblIndex9FoldingTrajectoryValue.Text = oString.ToString();
                                break;
                        }
                                            
                        // benchmark 797;
                        if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Folding.Benchmark))
                        {
                            switch (i)
                            {
                                case 0:
                                    lblIndex0FoldingBenchmarkValue.Text = voQueueDump.Queue.Index[i].Folding.Benchmark;
                                    break;
                                case 1:
                                    lblIndex1FoldingBenchmarkValue.Text = voQueueDump.Queue.Index[i].Folding.Benchmark;
                                    break;
                                case 2:
                                    lblIndex2FoldingBenchmarkValue.Text = voQueueDump.Queue.Index[i].Folding.Benchmark;
                                    break;
                                case 3:
                                    lblIndex3FoldingBenchmarkValue.Text = voQueueDump.Queue.Index[i].Folding.Benchmark;
                                    break;
                                case 4:
                                    lblIndex4FoldingBenchmarkValue.Text = voQueueDump.Queue.Index[i].Folding.Benchmark;
                                    break;
                                case 5:
                                    lblIndex5FoldingBenchmarkValue.Text = voQueueDump.Queue.Index[i].Folding.Benchmark;
                                    break;
                                case 6:
                                    lblIndex6FoldingBenchmarkValue.Text = voQueueDump.Queue.Index[i].Folding.Benchmark;
                                    break;
                                case 7:
                                    lblIndex7FoldingBenchmarkValue.Text = voQueueDump.Queue.Index[i].Folding.Benchmark;
                                    break;
                                case 8:
                                    lblIndex8FoldingBenchmarkValue.Text = voQueueDump.Queue.Index[i].Folding.Benchmark;
                                    break;
                                case 9:
                                    lblIndex9FoldingBenchmarkValue.Text = voQueueDump.Queue.Index[i].Folding.Benchmark;
                                    break;
                            }
                        }

                        // misc: 500, 300
                        if (  !String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Folding.Misc)
                           || !String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Folding.Other)
                           )
                        {
                            oString = new StringBuilder();
                            if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Folding.Misc))
                            {
                                oString.Append(voQueueDump.Queue.Index[i].Folding.Misc);

                                if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Folding.Other))
                                {
                                    oString.Append(", " + voQueueDump.Queue.Index[i].Folding.Other);
                                }
                            }
                            else if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Folding.Other))
                            {
                                oString.Append(voQueueDump.Queue.Index[i].Folding.Other);
                            }

                            switch (i)
                            {
                                case 0:
                                    lblIndex0FoldingMiscellaneousValue.Text = oString.ToString();
                                    break;
                                case 1:
                                    lblIndex1FoldingMiscellaneousValue.Text = oString.ToString();
                                    break;
                                case 2:
                                    lblIndex2FoldingMiscellaneousValue.Text = oString.ToString();
                                    break;
                                case 3:
                                    lblIndex3FoldingMiscellaneousValue.Text = oString.ToString();
                                    break;
                                case 4:
                                    lblIndex4FoldingMiscellaneousValue.Text = oString.ToString();
                                    break;
                                case 5:
                                    lblIndex5FoldingMiscellaneousValue.Text = oString.ToString();
                                    break;
                                case 6:
                                    lblIndex6FoldingMiscellaneousValue.Text = oString.ToString();
                                    break;
                                case 7:
                                    lblIndex7FoldingMiscellaneousValue.Text = oString.ToString();
                                    break;
                                case 8:
                                    lblIndex8FoldingMiscellaneousValue.Text = oString.ToString();
                                    break;
                                case 9:
                                    lblIndex9FoldingMiscellaneousValue.Text = oString.ToString();
                                    break;
                            }
                        }
                    }
                    // Genome: unit 36476, 7554, 656; benchmark 739; misc: 500, 200
                    else if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Genome.Unit))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0GenomeUnitValue.Text = voQueueDump.Queue.Index[i].Genome.Unit;
                                break;
                            case 1:
                                lblIndex1GenomeUnitValue.Text = voQueueDump.Queue.Index[i].Genome.Unit;
                                break;
                            case 2:
                                lblIndex2GenomeUnitValue.Text = voQueueDump.Queue.Index[i].Genome.Unit;
                                break;
                            case 3:
                                lblIndex3GenomeUnitValue.Text = voQueueDump.Queue.Index[i].Genome.Unit;
                                break;
                            case 4:
                                lblIndex4GenomeUnitValue.Text = voQueueDump.Queue.Index[i].Genome.Unit;
                                break;
                            case 5:
                                lblIndex5GenomeUnitValue.Text = voQueueDump.Queue.Index[i].Genome.Unit;
                                break;
                            case 6:
                                lblIndex6GenomeUnitValue.Text = voQueueDump.Queue.Index[i].Genome.Unit;
                                break;
                            case 7:
                                lblIndex7GenomeUnitValue.Text = voQueueDump.Queue.Index[i].Genome.Unit;
                                break;
                            case 8:
                                lblIndex8GenomeUnitValue.Text = voQueueDump.Queue.Index[i].Genome.Unit;
                                break;
                            case 9:
                                lblIndex9GenomeUnitValue.Text = voQueueDump.Queue.Index[i].Genome.Unit;
                                break;
                        }
                        
                        // benchmark 739; 
                        if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Genome.Benchmark))
                        {
                            switch (i)
                            {
                                case 0:
                                    lblIndex0GenomeBenchmarkValue.Text = voQueueDump.Queue.Index[i].Genome.Benchmark;
                                    break;
                                case 1:
                                    lblIndex1GenomeBenchmarkValue.Text = voQueueDump.Queue.Index[i].Genome.Benchmark;
                                    break;
                                case 2:
                                    lblIndex2GenomeBenchmarkValue.Text = voQueueDump.Queue.Index[i].Genome.Benchmark;
                                    break;
                                case 3:
                                    lblIndex3GenomeBenchmarkValue.Text = voQueueDump.Queue.Index[i].Genome.Benchmark;
                                    break;
                                case 4:
                                    lblIndex4GenomeBenchmarkValue.Text = voQueueDump.Queue.Index[i].Genome.Benchmark;
                                    break;
                                case 5:
                                    lblIndex5GenomeBenchmarkValue.Text = voQueueDump.Queue.Index[i].Genome.Benchmark;
                                    break;
                                case 6:
                                    lblIndex6GenomeBenchmarkValue.Text = voQueueDump.Queue.Index[i].Genome.Benchmark;
                                    break;
                                case 7:
                                    lblIndex7GenomeBenchmarkValue.Text = voQueueDump.Queue.Index[i].Genome.Benchmark;
                                    break;
                                case 8:
                                    lblIndex8GenomeBenchmarkValue.Text = voQueueDump.Queue.Index[i].Genome.Benchmark;
                                    break;
                                case 9:
                                    lblIndex9GenomeBenchmarkValue.Text = voQueueDump.Queue.Index[i].Genome.Benchmark;
                                    break;
                            }
                        }

                        // misc: 500, 200
                        if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Genome.Misc)
                           || !String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Genome.Other)
                           )
                        {
                            StringBuilder oString = new StringBuilder();
                            if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Genome.Misc))
                            {
                                oString.Append(voQueueDump.Queue.Index[i].Genome.Misc);

                                if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Genome.Other))
                                {
                                    oString.Append(", " + voQueueDump.Queue.Index[i].Genome.Other);
                                }
                            }
                            else if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Genome.Other))
                            {
                                oString.Append(voQueueDump.Queue.Index[i].Genome.Other);
                            }

                            switch (i)
                            {
                                case 0:
                                    lblIndex0GenomeMiscellaneousValue.Text = oString.ToString();
                                    break;
                                case 1:
                                    lblIndex1GenomeMiscellaneousValue.Text = oString.ToString();
                                    break;
                                case 2:
                                    lblIndex2GenomeMiscellaneousValue.Text = oString.ToString();
                                    break;
                                case 3:
                                    lblIndex3GenomeMiscellaneousValue.Text = oString.ToString();
                                    break;
                                case 4:
                                    lblIndex4GenomeMiscellaneousValue.Text = oString.ToString();
                                    break;
                                case 5:
                                    lblIndex5GenomeMiscellaneousValue.Text = oString.ToString();
                                    break;
                                case 6:
                                    lblIndex6GenomeMiscellaneousValue.Text = oString.ToString();
                                    break;
                                case 7:
                                    lblIndex7GenomeMiscellaneousValue.Text = oString.ToString();
                                    break;
                                case 8:
                                    lblIndex8GenomeMiscellaneousValue.Text = oString.ToString();
                                    break;
                                case 9:
                                    lblIndex9GenomeMiscellaneousValue.Text = oString.ToString();
                                    break;
                            }
                        }
                    }
                    
                    // Hide the Genome control if there is no Genome Unit in the queue index
                    if (String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Genome.Unit))
                    {
                        switch (i)
                        {
                            case 0:
                                grpbxIndex0Genome.Visible = false;
                                tlpIndex0.Height = (tlpIndex0.Height - grpbxIndex0Genome.Height);
                                break;
                            case 1:
                                grpbxIndex1Genome.Visible = false;
                                tlpIndex1.Height = (tlpIndex1.Height - grpbxIndex1Genome.Height);
                                break;
                            case 2:
                                grpbxIndex2Genome.Visible = false;
                                tlpIndex2.Height = (tlpIndex2.Height - grpbxIndex2Genome.Height);
                                break;
                            case 3:
                                grpbxIndex3Genome.Visible = false;
                                tlpIndex3.Height = (tlpIndex3.Height - grpbxIndex3Genome.Height);
                                break;
                            case 4:
                                grpbxIndex4Genome.Visible = false;
                                tlpIndex4.Height = (tlpIndex4.Height - grpbxIndex4Genome.Height);
                                break;
                            case 5:
                                grpbxIndex5Genome.Visible = false;
                                tlpIndex5.Height = (tlpIndex5.Height - grpbxIndex5Genome.Height);
                                break;
                            case 6:
                                grpbxIndex6Genome.Visible = false;
                                tlpIndex6.Height = (tlpIndex6.Height - grpbxIndex6Genome.Height);
                                break;
                            case 7:
                                grpbxIndex7Genome.Visible = false;
                                tlpIndex7.Height = (tlpIndex7.Height - grpbxIndex7Genome.Height);
                                break;
                            case 8:
                                grpbxIndex8Genome.Visible = false;
                                tlpIndex8.Height = (tlpIndex8.Height - grpbxIndex8Genome.Height);
                                break;
                            case 9:
                                grpbxIndex9Genome.Visible = false;
                                tlpIndex9.Height = (tlpIndex9.Height - grpbxIndex9Genome.Height);
                                break;
                        }
                    }
                    // Hide the Genome control if there is no Genome Unit in the queue index
                    if ( String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Folding.Run)
                      && String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Folding.Clone)
                      && String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Folding.Generation)
                        ) 
                    {
                        switch (i)
                        {
                            case 0:
                                grpbxIndex0Folding.Visible = false;
                                tlpIndex0.Height = (tlpIndex0.Height - grpbxIndex0Folding.Height);
                                break;
                            case 1:
                                grpbxIndex1Folding.Visible = false;
                                tlpIndex1.Height = (tlpIndex1.Height - grpbxIndex1Folding.Height);
                                break;
                            case 2:
                                grpbxIndex2Folding.Visible = false;
                                tlpIndex2.Height = (tlpIndex2.Height - grpbxIndex2Folding.Height);
                                break;
                            case 3:
                                grpbxIndex3Folding.Visible = false;
                                tlpIndex3.Height = (tlpIndex3.Height - grpbxIndex3Folding.Height);
                                break;
                            case 4:
                                grpbxIndex4Folding.Visible = false;
                                tlpIndex4.Height = (tlpIndex4.Height - grpbxIndex4Folding.Height);
                                break;
                            case 5:
                                grpbxIndex5Folding.Visible = false;
                                tlpIndex5.Height = (tlpIndex5.Height - grpbxIndex5Folding.Height);
                                break;
                            case 6:
                                grpbxIndex6Folding.Visible = false;
                                tlpIndex6.Height = (tlpIndex6.Height - grpbxIndex6Folding.Height);
                                break;
                            case 7:
                                grpbxIndex7Folding.Visible = false;
                                tlpIndex7.Height = (tlpIndex7.Height - grpbxIndex7Folding.Height);
                                break;
                            case 8:
                                grpbxIndex8Folding.Visible = false;
                                tlpIndex8.Height = (tlpIndex8.Height - grpbxIndex8Folding.Height);
                                break;
                            case 9:
                                grpbxIndex9Folding.Visible = false;
                                tlpIndex9.Height = (tlpIndex9.Height - grpbxIndex9Folding.Height);
                                break;
                        }
                    }
                    
                    // issue: Mon Aug  9 23:36:42 2004; begin: Mon Aug  9 23:41:10 2004
                    // end: Sun Aug 15 18:19:58 2004; due: Thu Aug 26 23:41:10 2004 (17 days)
                    //
                    // issue: Fri Aug 27 13:06:35 2004; begin: Fri Aug 27 13:06:47 2004
                    // end: Sat Aug 28 17:45:24 2004
                    //
                    // issue: Sat Sep 18 01:47:03 2004; begin: Sat Sep 18 01:47:11 2004
                    // end: Wed Sep 22 16:14:20 2004; expire: Sat Oct  2 01:47:11 2004 (14 days)
                    // 
                    // issue: Wed Sep 22 16:16:20 2004; begin: Wed Sep 22 16:16:56 2004
                    // expect: Tue Sep 28 22:59:03 2004; due: Thu Oct 28 15:16:56 2004 (36 days)

                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].IssueTimestamp))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0DateIssueValue.Text = voQueueDump.Queue.Index[i].IssueTimestamp;
                                break;
                            case 1:
                                lblIndex1DateIssueValue.Text = voQueueDump.Queue.Index[i].IssueTimestamp;
                                break;
                            case 2:
                                lblIndex2DateIssueValue.Text = voQueueDump.Queue.Index[i].IssueTimestamp;
                                break;
                            case 3:
                                lblIndex3DateIssueValue.Text = voQueueDump.Queue.Index[i].IssueTimestamp;
                                break;
                            case 4:
                                lblIndex4DateIssueValue.Text = voQueueDump.Queue.Index[i].IssueTimestamp;
                                break;
                            case 5:
                                lblIndex5DateIssueValue.Text = voQueueDump.Queue.Index[i].IssueTimestamp;
                                break;
                            case 6:
                                lblIndex6DateIssueValue.Text = voQueueDump.Queue.Index[i].IssueTimestamp;
                                break;
                            case 7:
                                lblIndex7DateIssueValue.Text = voQueueDump.Queue.Index[i].IssueTimestamp;
                                break;
                            case 8:
                                lblIndex8DateIssueValue.Text = voQueueDump.Queue.Index[i].IssueTimestamp;
                                break;
                            case 9:
                                lblIndex9DateIssueValue.Text = voQueueDump.Queue.Index[i].IssueTimestamp;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0DateIssueValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1DateIssueValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2DateIssueValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3DateIssueValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4DateIssueValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5DateIssueValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6DateIssueValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7DateIssueValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8DateIssueValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9DateIssueValue.Text = "n/a";
                                break;
                        }
                    }
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].BeginTimestamp))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0DateBeginValue.Text = voQueueDump.Queue.Index[i].BeginTimestamp;
                                break;
                            case 1:
                                lblIndex1DateBeginValue.Text = voQueueDump.Queue.Index[i].BeginTimestamp;
                                break;
                            case 2:
                                lblIndex2DateBeginValue.Text = voQueueDump.Queue.Index[i].BeginTimestamp;
                                break;
                            case 3:
                                lblIndex3DateBeginValue.Text = voQueueDump.Queue.Index[i].BeginTimestamp;
                                break;
                            case 4:
                                lblIndex4DateBeginValue.Text = voQueueDump.Queue.Index[i].BeginTimestamp;
                                break;
                            case 5:
                                lblIndex5DateBeginValue.Text = voQueueDump.Queue.Index[i].BeginTimestamp;
                                break;
                            case 6:
                                lblIndex6DateBeginValue.Text = voQueueDump.Queue.Index[i].BeginTimestamp;
                                break;
                            case 7:
                                lblIndex7DateBeginValue.Text = voQueueDump.Queue.Index[i].BeginTimestamp;
                                break;
                            case 8:
                                lblIndex8DateBeginValue.Text = voQueueDump.Queue.Index[i].BeginTimestamp;
                                break;
                            case 9:
                                lblIndex9DateBeginValue.Text = voQueueDump.Queue.Index[i].BeginTimestamp;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0DateBeginValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1DateBeginValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2DateBeginValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3DateBeginValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4DateBeginValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5DateBeginValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6DateBeginValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7DateBeginValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8DateBeginValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9DateBeginValue.Text = "n/a";
                                break;
                        }
                    }
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].EndTimestamp))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0DateEndValue.Text = voQueueDump.Queue.Index[i].EndTimestamp;
                                break;
                            case 1:
                                lblIndex1DateEndValue.Text = voQueueDump.Queue.Index[i].EndTimestamp;
                                break;
                            case 2:
                                lblIndex2DateEndValue.Text = voQueueDump.Queue.Index[i].EndTimestamp;
                                break;
                            case 3:
                                lblIndex3DateEndValue.Text = voQueueDump.Queue.Index[i].EndTimestamp;
                                break;
                            case 4:
                                lblIndex4DateEndValue.Text = voQueueDump.Queue.Index[i].EndTimestamp;
                                break;
                            case 5:
                                lblIndex5DateEndValue.Text = voQueueDump.Queue.Index[i].EndTimestamp;
                                break;
                            case 6:
                                lblIndex6DateEndValue.Text = voQueueDump.Queue.Index[i].EndTimestamp;
                                break;
                            case 7:
                                lblIndex7DateEndValue.Text = voQueueDump.Queue.Index[i].EndTimestamp;
                                break;
                            case 8:
                                lblIndex8DateEndValue.Text = voQueueDump.Queue.Index[i].EndTimestamp;
                                break;
                            case 9:
                                lblIndex9DateEndValue.Text = voQueueDump.Queue.Index[i].EndTimestamp;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0DateEndValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1DateEndValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2DateEndValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3DateEndValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4DateEndValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5DateEndValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6DateEndValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7DateEndValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8DateEndValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9DateEndValue.Text = "n/a";
                                break;
                        }
                    }
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].ExpectTimestamp))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0DateExpectValue.Text = voQueueDump.Queue.Index[i].ExpectTimestamp;
                                break;
                            case 1:
                                lblIndex1DateExpectValue.Text = voQueueDump.Queue.Index[i].ExpectTimestamp;
                                break;
                            case 2:
                                lblIndex2DateExpectValue.Text = voQueueDump.Queue.Index[i].ExpectTimestamp;
                                break;
                            case 3:
                                lblIndex3DateExpectValue.Text = voQueueDump.Queue.Index[i].ExpectTimestamp;
                                break;
                            case 4:
                                lblIndex4DateExpectValue.Text = voQueueDump.Queue.Index[i].ExpectTimestamp;
                                break;
                            case 5:
                                lblIndex5DateExpectValue.Text = voQueueDump.Queue.Index[i].ExpectTimestamp;
                                break;
                            case 6:
                                lblIndex6DateExpectValue.Text = voQueueDump.Queue.Index[i].ExpectTimestamp;
                                break;
                            case 7:
                                lblIndex7DateExpectValue.Text = voQueueDump.Queue.Index[i].ExpectTimestamp;
                                break;
                            case 8:
                                lblIndex8DateExpectValue.Text = voQueueDump.Queue.Index[i].ExpectTimestamp;
                                break;
                            case 9:
                                lblIndex9DateExpectValue.Text = voQueueDump.Queue.Index[i].ExpectTimestamp;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0DateExpectValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1DateExpectValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2DateExpectValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3DateExpectValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4DateExpectValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5DateExpectValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6DateExpectValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7DateExpectValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8DateExpectValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9DateExpectValue.Text = "n/a";
                                break;
                        }
                    }
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].DueTimestamp))
                    {
                        if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Deadline))
                        {
                            StringBuilder oString = new StringBuilder(voQueueDump.Queue.Index[i].DueTimestamp);
                            oString.AppendFormat(" ({0})", voQueueDump.Queue.Index[i].Deadline);

                            switch (i)
                            {
                                case 0:
                                    lblIndex0DateDueValue.Text = oString.ToString();
                                    break;
                                case 1:
                                    lblIndex1DateDueValue.Text = oString.ToString();
                                    break;
                                case 2:
                                    lblIndex2DateDueValue.Text = oString.ToString();
                                    break;
                                case 3:
                                    lblIndex3DateDueValue.Text = oString.ToString();
                                    break;
                                case 4:
                                    lblIndex4DateDueValue.Text = oString.ToString();
                                    break;
                                case 5:
                                    lblIndex5DateDueValue.Text = oString.ToString();
                                    break;
                                case 6:
                                    lblIndex6DateDueValue.Text = oString.ToString();
                                    break;
                                case 7:
                                    lblIndex7DateDueValue.Text = oString.ToString();
                                    break;
                                case 8:
                                    lblIndex8DateDueValue.Text = oString.ToString();
                                    break;
                                case 9:
                                    lblIndex9DateDueValue.Text = oString.ToString();
                                    break;
                            }
                        }
                        else
                        {
                            switch (i)
                            {
                                case 0:
                                    lblIndex0DateDueValue.Text = voQueueDump.Queue.Index[i].DueTimestamp;
                                    break;
                                case 1:
                                    lblIndex1DateDueValue.Text = voQueueDump.Queue.Index[i].DueTimestamp;
                                    break;
                                case 2:
                                    lblIndex2DateDueValue.Text = voQueueDump.Queue.Index[i].DueTimestamp;
                                    break;
                                case 3:
                                    lblIndex3DateDueValue.Text = voQueueDump.Queue.Index[i].DueTimestamp;
                                    break;
                                case 4:
                                    lblIndex4DateDueValue.Text = voQueueDump.Queue.Index[i].DueTimestamp;
                                    break;
                                case 5:
                                    lblIndex5DateDueValue.Text = voQueueDump.Queue.Index[i].DueTimestamp;
                                    break;
                                case 6:
                                    lblIndex6DateDueValue.Text = voQueueDump.Queue.Index[i].DueTimestamp;
                                    break;
                                case 7:
                                    lblIndex7DateDueValue.Text = voQueueDump.Queue.Index[i].DueTimestamp;
                                    break;
                                case 8:
                                    lblIndex8DateDueValue.Text = voQueueDump.Queue.Index[i].DueTimestamp;
                                    break;
                                case 9:
                                    lblIndex9DateDueValue.Text = voQueueDump.Queue.Index[i].DueTimestamp;
                                    break;
                            }
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0DateDueValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1DateDueValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2DateDueValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3DateDueValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4DateDueValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5DateDueValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6DateDueValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7DateDueValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8DateDueValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9DateDueValue.Text = "n/a";
                                break;
                        }
                    }
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].ExpireTimestamp))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0DateExpireValue.Text = voQueueDump.Queue.Index[i].ExpireTimestamp;
                                break;
                            case 1:
                                lblIndex1DateExpireValue.Text = voQueueDump.Queue.Index[i].ExpireTimestamp;
                                break;
                            case 2:
                                lblIndex2DateExpireValue.Text = voQueueDump.Queue.Index[i].ExpireTimestamp;
                                break;
                            case 3:
                                lblIndex3DateExpireValue.Text = voQueueDump.Queue.Index[i].ExpireTimestamp;
                                break;
                            case 4:
                                lblIndex4DateExpireValue.Text = voQueueDump.Queue.Index[i].ExpireTimestamp;
                                break;
                            case 5:
                                lblIndex5DateExpireValue.Text = voQueueDump.Queue.Index[i].ExpireTimestamp;
                                break;
                            case 6:
                                lblIndex6DateExpireValue.Text = voQueueDump.Queue.Index[i].ExpireTimestamp;
                                break;
                            case 7:
                                lblIndex7DateExpireValue.Text = voQueueDump.Queue.Index[i].ExpireTimestamp;
                                break;
                            case 8:
                                lblIndex8DateExpireValue.Text = voQueueDump.Queue.Index[i].ExpireTimestamp;
                                break;
                            case 9:
                                lblIndex9DateExpireValue.Text = voQueueDump.Queue.Index[i].ExpireTimestamp;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0DateExpireValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1DateExpireValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2DateExpireValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3DateExpireValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4DateExpireValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5DateExpireValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6DateExpireValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7DateExpireValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8DateExpireValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9DateExpireValue.Text = "n/a";
                                break;
                        }
                    }
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].PreferredTimestamp))
                    {
                        StringBuilder oString = new StringBuilder(voQueueDump.Queue.Index[i].PreferredTimestamp);
                        oString.AppendFormat(" ({0})", voQueueDump.Queue.Index[i].PreferredDeadline);

                        switch (i)
                        {
                            case 0:
                                lblIndex0DatePreferredValue.Text = oString.ToString();
                                break;
                            case 1:
                                lblIndex1DatePreferredValue.Text = oString.ToString();
                                break;
                            case 2:
                                lblIndex2DatePreferredValue.Text = oString.ToString();
                                break;
                            case 3:
                                lblIndex3DatePreferredValue.Text = oString.ToString();
                                break;
                            case 4:
                                lblIndex4DatePreferredValue.Text = oString.ToString();
                                break;
                            case 5:
                                lblIndex5DatePreferredValue.Text = oString.ToString();
                                break;
                            case 6:
                                lblIndex6DatePreferredValue.Text = oString.ToString();
                                break;
                            case 7:
                                lblIndex7DatePreferredValue.Text = oString.ToString();
                                break;
                            case 8:
                                lblIndex8DatePreferredValue.Text = oString.ToString();
                                break;
                            case 9:
                                lblIndex9DatePreferredValue.Text = oString.ToString();
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0DatePreferredValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1DatePreferredValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2DatePreferredValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3DatePreferredValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4DatePreferredValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5DatePreferredValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6DatePreferredValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7DatePreferredValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8DatePreferredValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9DatePreferredValue.Text = "n/a";
                                break;
                        }
                    }

                    // core URL: http://www.stanford.edu/~pande/Linux/x86/Core_78.fah (V1.68)
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Core.URL))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0CoreUrlValue.Text = voQueueDump.Queue.Index[i].Core.URL;
                                break;
                            case 1:
                                lblIndex1CoreUrlValue.Text = voQueueDump.Queue.Index[i].Core.URL;
                                break;
                            case 2:
                                lblIndex2CoreUrlValue.Text = voQueueDump.Queue.Index[i].Core.URL;
                                break;
                            case 3:
                                lblIndex3CoreUrlValue.Text = voQueueDump.Queue.Index[i].Core.URL;
                                break;
                            case 4:
                                lblIndex4CoreUrlValue.Text = voQueueDump.Queue.Index[i].Core.URL;
                                break;
                            case 5:
                                lblIndex5CoreUrlValue.Text = voQueueDump.Queue.Index[i].Core.URL;
                                break;
                            case 6:
                                lblIndex6CoreUrlValue.Text = voQueueDump.Queue.Index[i].Core.URL;
                                break;
                            case 7:
                                lblIndex7CoreUrlValue.Text = voQueueDump.Queue.Index[i].Core.URL;
                                break;
                            case 8:
                                lblIndex8CoreUrlValue.Text = voQueueDump.Queue.Index[i].Core.URL;
                                break;
                            case 9:
                                lblIndex9CoreUrlValue.Text = voQueueDump.Queue.Index[i].Core.URL;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0CoreUrlValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1CoreUrlValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2CoreUrlValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3CoreUrlValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4CoreUrlValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5CoreUrlValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6CoreUrlValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7CoreUrlValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8CoreUrlValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9CoreUrlValue.Text = "n/a";
                                break;
                        }
                    }
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Core.Version))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0CoreVersionValue.Text = voQueueDump.Queue.Index[i].Core.Version;
                                break;
                            case 1:
                                lblIndex1CoreVersionValue.Text = voQueueDump.Queue.Index[i].Core.Version;
                                break;
                            case 2:
                                lblIndex2CoreVersionValue.Text = voQueueDump.Queue.Index[i].Core.Version;
                                break;
                            case 3:
                                lblIndex3CoreVersionValue.Text = voQueueDump.Queue.Index[i].Core.Version;
                                break;
                            case 4:
                                lblIndex4CoreVersionValue.Text = voQueueDump.Queue.Index[i].Core.Version;
                                break;
                            case 5:
                                lblIndex5CoreVersionValue.Text = voQueueDump.Queue.Index[i].Core.Version;
                                break;
                            case 6:
                                lblIndex6CoreVersionValue.Text = voQueueDump.Queue.Index[i].Core.Version;
                                break;
                            case 7:
                                lblIndex7CoreVersionValue.Text = voQueueDump.Queue.Index[i].Core.Version;
                                break;
                            case 8:
                                lblIndex8CoreVersionValue.Text = voQueueDump.Queue.Index[i].Core.Version;
                                break;
                            case 9:
                                lblIndex9CoreVersionValue.Text = voQueueDump.Queue.Index[i].Core.Version;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0CoreVersionValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1CoreVersionValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2CoreVersionValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3CoreVersionValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4CoreVersionValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5CoreVersionValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6CoreVersionValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7CoreVersionValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8CoreVersionValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9CoreVersionValue.Text = "n/a";
                                break;
                        }
                    }

                    // CPU: 1,0 x86; OS: 4,0 Linux
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].CPU.CosmType))
                    {
                        StringBuilder oString = new StringBuilder(voQueueDump.Queue.Index[i].CPU.CosmType);
                        oString.Append(",");
                        oString.Append(voQueueDump.Queue.Index[i].CPU.CosmSubtype);

                        switch (i)
                        {
                            case 0:
                                lblIndex0CPUTypeValue.Text = oString.ToString();
                                break;
                            case 1:
                                lblIndex1CPUTypeValue.Text = oString.ToString();
                                break;
                            case 2:
                                lblIndex2CPUTypeValue.Text = oString.ToString();
                                break;
                            case 3:
                                lblIndex3CPUTypeValue.Text = oString.ToString();
                                break;
                            case 4:
                                lblIndex4CPUTypeValue.Text = oString.ToString();
                                break;
                            case 5:
                                lblIndex5CPUTypeValue.Text = oString.ToString();
                                break;
                            case 6:
                                lblIndex6CPUTypeValue.Text = oString.ToString();
                                break;
                            case 7:
                                lblIndex7CPUTypeValue.Text = oString.ToString();
                                break;
                            case 8:
                                lblIndex8CPUTypeValue.Text = oString.ToString();
                                break;
                            case 9:
                                lblIndex9CPUTypeValue.Text = oString.ToString();
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0CPUTypeValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1CPUTypeValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2CPUTypeValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3CPUTypeValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4CPUTypeValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5CPUTypeValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6CPUTypeValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7CPUTypeValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8CPUTypeValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9CPUTypeValue.Text = "n/a";
                                break;
                        }
                    }
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].CPU.Name))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0CPUNameValue.Text = voQueueDump.Queue.Index[i].CPU.Name;
                                break;
                            case 1:
                                lblIndex1CPUNameValue.Text = voQueueDump.Queue.Index[i].CPU.Name;
                                break;
                            case 2:
                                lblIndex2CPUNameValue.Text = voQueueDump.Queue.Index[i].CPU.Name;
                                break;
                            case 3:
                                lblIndex3CPUNameValue.Text = voQueueDump.Queue.Index[i].CPU.Name;
                                break;
                            case 4:
                                lblIndex4CPUNameValue.Text = voQueueDump.Queue.Index[i].CPU.Name;
                                break;
                            case 5:
                                lblIndex5CPUNameValue.Text = voQueueDump.Queue.Index[i].CPU.Name;
                                break;
                            case 6:
                                lblIndex6CPUNameValue.Text = voQueueDump.Queue.Index[i].CPU.Name;
                                break;
                            case 7:
                                lblIndex7CPUNameValue.Text = voQueueDump.Queue.Index[i].CPU.Name;
                                break;
                            case 8:
                                lblIndex8CPUNameValue.Text = voQueueDump.Queue.Index[i].CPU.Name;
                                break;
                            case 9:
                                lblIndex9CPUNameValue.Text = voQueueDump.Queue.Index[i].CPU.Name;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0CPUNameValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1CPUNameValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2CPUNameValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3CPUNameValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4CPUNameValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5CPUNameValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6CPUNameValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7CPUNameValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8CPUNameValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9CPUNameValue.Text = "n/a";
                                break;
                        }
                    }
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].OS.CosmType))
                    {
                        StringBuilder oString = new StringBuilder(voQueueDump.Queue.Index[i].OS.CosmType);
                        oString.Append(",");
                        oString.Append(voQueueDump.Queue.Index[i].OS.CosmSubtype);

                        switch (i)
                        {
                            case 0:
                                lblIndex0OSTypeValue.Text = oString.ToString();
                                break;
                            case 1:
                                lblIndex1OSTypeValue.Text = oString.ToString();
                                break;
                            case 2:
                                lblIndex2OSTypeValue.Text = oString.ToString();
                                break;
                            case 3:
                                lblIndex3OSTypeValue.Text = oString.ToString();
                                break;
                            case 4:
                                lblIndex4OSTypeValue.Text = oString.ToString();
                                break;
                            case 5:
                                lblIndex5OSTypeValue.Text = oString.ToString();
                                break;
                            case 6:
                                lblIndex6OSTypeValue.Text = oString.ToString();
                                break;
                            case 7:
                                lblIndex7OSTypeValue.Text = oString.ToString();
                                break;
                            case 8:
                                lblIndex8OSTypeValue.Text = oString.ToString();
                                break;
                            case 9:
                                lblIndex9OSTypeValue.Text = oString.ToString();
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0OSTypeValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1OSTypeValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2OSTypeValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3OSTypeValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4OSTypeValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5OSTypeValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6OSTypeValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7OSTypeValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8OSTypeValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9OSTypeValue.Text = "n/a";
                                break;
                        }
                    }
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].OS.Name))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0OSNameValue.Text = voQueueDump.Queue.Index[i].OS.Name;
                                break;
                            case 1:
                                lblIndex1OSNameValue.Text = voQueueDump.Queue.Index[i].OS.Name;
                                break;
                            case 2:
                                lblIndex2OSNameValue.Text = voQueueDump.Queue.Index[i].OS.Name;
                                break;
                            case 3:
                                lblIndex3OSNameValue.Text = voQueueDump.Queue.Index[i].OS.Name;
                                break;
                            case 4:
                                lblIndex4OSNameValue.Text = voQueueDump.Queue.Index[i].OS.Name;
                                break;
                            case 5:
                                lblIndex5OSNameValue.Text = voQueueDump.Queue.Index[i].OS.Name;
                                break;
                            case 6:
                                lblIndex6OSNameValue.Text = voQueueDump.Queue.Index[i].OS.Name;
                                break;
                            case 7:
                                lblIndex7OSNameValue.Text = voQueueDump.Queue.Index[i].OS.Name;
                                break;
                            case 8:
                                lblIndex8OSNameValue.Text = voQueueDump.Queue.Index[i].OS.Name;
                                break;
                            case 9:
                                lblIndex9OSNameValue.Text = voQueueDump.Queue.Index[i].OS.Name;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0OSNameValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1OSNameValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2OSNameValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3OSNameValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4OSNameValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5OSNameValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6OSNameValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7OSNameValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8OSNameValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9OSNameValue.Text = "n/a";
                                break;
                        }
                    }

                    // smp cores: 4
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].SMPCores))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0CPUSMPCoresValue.Text = voQueueDump.Queue.Index[i].SMPCores;
                                break;
                            case 1:
                                lblIndex1CPUSMPCoresValue.Text = voQueueDump.Queue.Index[i].SMPCores;
                                break;
                            case 2:
                                lblIndex2CPUSMPCoresValue.Text = voQueueDump.Queue.Index[i].SMPCores;
                                break;
                            case 3:
                                lblIndex3CPUSMPCoresValue.Text = voQueueDump.Queue.Index[i].SMPCores;
                                break;
                            case 4:
                                lblIndex4CPUSMPCoresValue.Text = voQueueDump.Queue.Index[i].SMPCores;
                                break;
                            case 5:
                                lblIndex5CPUSMPCoresValue.Text = voQueueDump.Queue.Index[i].SMPCores;
                                break;
                            case 6:
                                lblIndex6CPUSMPCoresValue.Text = voQueueDump.Queue.Index[i].SMPCores;
                                break;
                            case 7:
                                lblIndex7CPUSMPCoresValue.Text = voQueueDump.Queue.Index[i].SMPCores;
                                break;
                            case 8:
                                lblIndex8CPUSMPCoresValue.Text = voQueueDump.Queue.Index[i].SMPCores;
                                break;
                            case 9:
                                lblIndex9CPUSMPCoresValue.Text = voQueueDump.Queue.Index[i].SMPCores;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0CPUSMPCoresValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1CPUSMPCoresValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2CPUSMPCoresValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3CPUSMPCoresValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4CPUSMPCoresValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5CPUSMPCoresValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6CPUSMPCoresValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7CPUSMPCoresValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8CPUSMPCoresValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9CPUSMPCoresValue.Text = "n/a";
                                break;
                        }
                    }

                    // smp cores: 4
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].SMPCores))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0CPUSMPCoresValue.Text = voQueueDump.Queue.Index[i].SMPCores;
                                break;
                            case 1:
                                lblIndex1CPUSMPCoresValue.Text = voQueueDump.Queue.Index[i].SMPCores;
                                break;
                            case 2:
                                lblIndex2CPUSMPCoresValue.Text = voQueueDump.Queue.Index[i].SMPCores;
                                break;
                            case 3:
                                lblIndex3CPUSMPCoresValue.Text = voQueueDump.Queue.Index[i].SMPCores;
                                break;
                            case 4:
                                lblIndex4CPUSMPCoresValue.Text = voQueueDump.Queue.Index[i].SMPCores;
                                break;
                            case 5:
                                lblIndex5CPUSMPCoresValue.Text = voQueueDump.Queue.Index[i].SMPCores;
                                break;
                            case 6:
                                lblIndex6CPUSMPCoresValue.Text = voQueueDump.Queue.Index[i].SMPCores;
                                break;
                            case 7:
                                lblIndex7CPUSMPCoresValue.Text = voQueueDump.Queue.Index[i].SMPCores;
                                break;
                            case 8:
                                lblIndex8CPUSMPCoresValue.Text = voQueueDump.Queue.Index[i].SMPCores;
                                break;
                            case 9:
                                lblIndex9CPUSMPCoresValue.Text = voQueueDump.Queue.Index[i].SMPCores;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0CPUSMPCoresValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1CPUSMPCoresValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2CPUSMPCoresValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3CPUSMPCoresValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4CPUSMPCoresValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5CPUSMPCoresValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6CPUSMPCoresValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7CPUSMPCoresValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8CPUSMPCoresValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9CPUSMPCoresValue.Text = "n/a";
                                break;
                        }
                    }

                    // flops: 1064231104 (1064.231104 megaflops)
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Flops))
                    {
                        StringBuilder oString = new StringBuilder(voQueueDump.Queue.Index[i].Flops);

                        if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Megaflops))
                        {
                            oString.AppendFormat(" ({0} megaflops)", voQueueDump.Queue.Index[i].Megaflops);
                        }

                        switch (i)
                        {
                            case 0:
                                lblIndex0CPUFlopsValue.Text = oString.ToString();
                                break;
                            case 1:
                                lblIndex1CPUFlopsValue.Text = oString.ToString();
                                break;
                            case 2:
                                lblIndex2CPUFlopsValue.Text = oString.ToString();
                                break;
                            case 3:
                                lblIndex3CPUFlopsValue.Text = oString.ToString();
                                break;
                            case 4:
                                lblIndex4CPUFlopsValue.Text = oString.ToString();
                                break;
                            case 5:
                                lblIndex5CPUFlopsValue.Text = oString.ToString();
                                break;
                            case 6:
                                lblIndex6CPUFlopsValue.Text = oString.ToString();
                                break;
                            case 7:
                                lblIndex7CPUFlopsValue.Text = oString.ToString();
                                break;
                            case 8:
                                lblIndex8CPUFlopsValue.Text = oString.ToString();
                                break;
                            case 9:
                                lblIndex9CPUFlopsValue.Text = oString.ToString();
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0CPUFlopsValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1CPUFlopsValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2CPUFlopsValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3CPUFlopsValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4CPUFlopsValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5CPUFlopsValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6CPUFlopsValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7CPUFlopsValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8CPUFlopsValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9CPUFlopsValue.Text = "n/a";
                                break;
                        }
                    }

                    // assignment info (le): Mon Aug  9 23:36:38 2004; AC1213B0
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].AssignmentInfo.ByteOrder))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0AssignmentInfoByteOrderValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.ByteOrder;
                                break;
                            case 1:
                                lblIndex1AssignmentInfoByteOrderValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.ByteOrder;
                                break;
                            case 2:
                                lblIndex2AssignmentInfoByteOrderValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.ByteOrder;
                                break;
                            case 3:
                                lblIndex3AssignmentInfoByteOrderValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.ByteOrder;
                                break;
                            case 4:
                                lblIndex4AssignmentInfoByteOrderValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.ByteOrder;
                                break;
                            case 5:
                                lblIndex5AssignmentInfoByteOrderValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.ByteOrder;
                                break;
                            case 6:
                                lblIndex6AssignmentInfoByteOrderValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.ByteOrder;
                                break;
                            case 7:
                                lblIndex7AssignmentInfoByteOrderValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.ByteOrder;
                                break;
                            case 8:
                                lblIndex8AssignmentInfoByteOrderValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.ByteOrder;
                                break;
                            case 9:
                                lblIndex9AssignmentInfoByteOrderValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.ByteOrder;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0AssignmentInfoByteOrderValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1AssignmentInfoByteOrderValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2AssignmentInfoByteOrderValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3AssignmentInfoByteOrderValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4AssignmentInfoByteOrderValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5AssignmentInfoByteOrderValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6AssignmentInfoByteOrderValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7AssignmentInfoByteOrderValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8AssignmentInfoByteOrderValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9AssignmentInfoByteOrderValue.Text = "n/a";
                                break;
                        }
                    }
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].AssignmentInfo.Timestamp))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0AssignmentInfoTimestampValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.Timestamp;
                                break;
                            case 1:
                                lblIndex1AssignmentInfoTimestampValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.Timestamp;
                                break;
                            case 2:
                                lblIndex2AssignmentInfoTimestampValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.Timestamp;
                                break;
                            case 3:
                                lblIndex3AssignmentInfoTimestampValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.Timestamp;
                                break;
                            case 4:
                                lblIndex4AssignmentInfoTimestampValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.Timestamp;
                                break;
                            case 5:
                                lblIndex5AssignmentInfoTimestampValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.Timestamp;
                                break;
                            case 6:
                                lblIndex6AssignmentInfoTimestampValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.Timestamp;
                                break;
                            case 7:
                                lblIndex7AssignmentInfoTimestampValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.Timestamp;
                                break;
                            case 8:
                                lblIndex8AssignmentInfoTimestampValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.Timestamp;
                                break;
                            case 9:
                                lblIndex9AssignmentInfoTimestampValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.Timestamp;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0AssignmentInfoTimestampValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1AssignmentInfoTimestampValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2AssignmentInfoTimestampValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3AssignmentInfoTimestampValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4AssignmentInfoTimestampValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5AssignmentInfoTimestampValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6AssignmentInfoTimestampValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7AssignmentInfoTimestampValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8AssignmentInfoTimestampValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9AssignmentInfoTimestampValue.Text = "n/a";
                                break;
                        }
                    }
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].AssignmentInfo.Checksum))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0AssignmentInfoChecksumValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.Checksum;
                                break;
                            case 1:
                                lblIndex1AssignmentInfoChecksumValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.Checksum;
                                break;
                            case 2:
                                lblIndex2AssignmentInfoChecksumValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.Checksum;
                                break;
                            case 3:
                                lblIndex3AssignmentInfoChecksumValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.Checksum;
                                break;
                            case 4:
                                lblIndex4AssignmentInfoChecksumValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.Checksum;
                                break;
                            case 5:
                                lblIndex5AssignmentInfoChecksumValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.Checksum;
                                break;
                            case 6:
                                lblIndex6AssignmentInfoChecksumValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.Checksum;
                                break;
                            case 7:
                                lblIndex7AssignmentInfoChecksumValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.Checksum;
                                break;
                            case 8:
                                lblIndex8AssignmentInfoChecksumValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.Checksum;
                                break;
                            case 9:
                                lblIndex9AssignmentInfoChecksumValue.Text = voQueueDump.Queue.Index[i].AssignmentInfo.Checksum;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0AssignmentInfoChecksumValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1AssignmentInfoChecksumValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2AssignmentInfoChecksumValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3AssignmentInfoChecksumValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4AssignmentInfoChecksumValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5AssignmentInfoChecksumValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6AssignmentInfoChecksumValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7AssignmentInfoChecksumValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8AssignmentInfoChecksumValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9AssignmentInfoChecksumValue.Text = "n/a";
                                break;
                        }
                    }

                    // user: rph_iv; team: 0; ID: 3539220A7A46065D; mach ID: 1
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Username))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0ConfigurationUsernameValue.Text = voQueueDump.Queue.Index[i].Username;
                                break;
                            case 1:
                                lblIndex1ConfigurationUsernameValue.Text = voQueueDump.Queue.Index[i].Username;
                                break;
                            case 2:
                                lblIndex2ConfigurationUsernameValue.Text = voQueueDump.Queue.Index[i].Username;
                                break;
                            case 3:
                                lblIndex3ConfigurationUsernameValue.Text = voQueueDump.Queue.Index[i].Username;
                                break;
                            case 4:
                                lblIndex4ConfigurationUsernameValue.Text = voQueueDump.Queue.Index[i].Username;
                                break;
                            case 5:
                                lblIndex5ConfigurationUsernameValue.Text = voQueueDump.Queue.Index[i].Username;
                                break;
                            case 6:
                                lblIndex6ConfigurationUsernameValue.Text = voQueueDump.Queue.Index[i].Username;
                                break;
                            case 7:
                                lblIndex7ConfigurationUsernameValue.Text = voQueueDump.Queue.Index[i].Username;
                                break;
                            case 8:
                                lblIndex8ConfigurationUsernameValue.Text = voQueueDump.Queue.Index[i].Username;
                                break;
                            case 9:
                                lblIndex9ConfigurationUsernameValue.Text = voQueueDump.Queue.Index[i].Username;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0ConfigurationUsernameValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1ConfigurationUsernameValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2ConfigurationUsernameValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3ConfigurationUsernameValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4ConfigurationUsernameValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5ConfigurationUsernameValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6ConfigurationUsernameValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7ConfigurationUsernameValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8ConfigurationUsernameValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9ConfigurationUsernameValue.Text = "n/a";
                                break;
                        }
                    }
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Team))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0ConfigurationTeamValue.Text = voQueueDump.Queue.Index[i].Team;
                                break;
                            case 1:
                                lblIndex1ConfigurationTeamValue.Text = voQueueDump.Queue.Index[i].Team;
                                break;
                            case 2:
                                lblIndex2ConfigurationTeamValue.Text = voQueueDump.Queue.Index[i].Team;
                                break;
                            case 3:
                                lblIndex3ConfigurationTeamValue.Text = voQueueDump.Queue.Index[i].Team;
                                break;
                            case 4:
                                lblIndex4ConfigurationTeamValue.Text = voQueueDump.Queue.Index[i].Team;
                                break;
                            case 5:
                                lblIndex5ConfigurationTeamValue.Text = voQueueDump.Queue.Index[i].Team;
                                break;
                            case 6:
                                lblIndex6ConfigurationTeamValue.Text = voQueueDump.Queue.Index[i].Team;
                                break;
                            case 7:
                                lblIndex7ConfigurationTeamValue.Text = voQueueDump.Queue.Index[i].Team;
                                break;
                            case 8:
                                lblIndex8ConfigurationTeamValue.Text = voQueueDump.Queue.Index[i].Team;
                                break;
                            case 9:
                                lblIndex9ConfigurationTeamValue.Text = voQueueDump.Queue.Index[i].Team;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0ConfigurationTeamValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1ConfigurationTeamValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2ConfigurationTeamValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3ConfigurationTeamValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4ConfigurationTeamValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5ConfigurationTeamValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6ConfigurationTeamValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7ConfigurationTeamValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8ConfigurationTeamValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9ConfigurationTeamValue.Text = "n/a";
                                break;
                        }
                    }
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].ID))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0ConfigurationIDValue.Text = voQueueDump.Queue.Index[i].ID;
                                break;
                            case 1:
                                lblIndex1ConfigurationIDValue.Text = voQueueDump.Queue.Index[i].ID;
                                break;
                            case 2:
                                lblIndex2ConfigurationIDValue.Text = voQueueDump.Queue.Index[i].ID;
                                break;
                            case 3:
                                lblIndex3ConfigurationIDValue.Text = voQueueDump.Queue.Index[i].ID;
                                break;
                            case 4:
                                lblIndex4ConfigurationIDValue.Text = voQueueDump.Queue.Index[i].ID;
                                break;
                            case 5:
                                lblIndex5ConfigurationIDValue.Text = voQueueDump.Queue.Index[i].ID;
                                break;
                            case 6:
                                lblIndex6ConfigurationIDValue.Text = voQueueDump.Queue.Index[i].ID;
                                break;
                            case 7:
                                lblIndex7ConfigurationIDValue.Text = voQueueDump.Queue.Index[i].ID;
                                break;
                            case 8:
                                lblIndex8ConfigurationIDValue.Text = voQueueDump.Queue.Index[i].ID;
                                break;
                            case 9:
                                lblIndex9ConfigurationIDValue.Text = voQueueDump.Queue.Index[i].ID;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0ConfigurationIDValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1ConfigurationIDValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2ConfigurationIDValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3ConfigurationIDValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4ConfigurationIDValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5ConfigurationIDValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6ConfigurationIDValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7ConfigurationIDValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8ConfigurationIDValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9ConfigurationIDValue.Text = "n/a";
                                break;
                        }
                    }
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].MachineID))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0ConfigurationMachineIDValue.Text = voQueueDump.Queue.Index[i].MachineID;
                                break;
                            case 1:
                                lblIndex1ConfigurationMachineIDValue.Text = voQueueDump.Queue.Index[i].MachineID;
                                break;
                            case 2:
                                lblIndex2ConfigurationMachineIDValue.Text = voQueueDump.Queue.Index[i].MachineID;
                                break;
                            case 3:
                                lblIndex3ConfigurationMachineIDValue.Text = voQueueDump.Queue.Index[i].MachineID;
                                break;
                            case 4:
                                lblIndex4ConfigurationMachineIDValue.Text = voQueueDump.Queue.Index[i].MachineID;
                                break;
                            case 5:
                                lblIndex5ConfigurationMachineIDValue.Text = voQueueDump.Queue.Index[i].MachineID;
                                break;
                            case 6:
                                lblIndex6ConfigurationMachineIDValue.Text = voQueueDump.Queue.Index[i].MachineID;
                                break;
                            case 7:
                                lblIndex7ConfigurationMachineIDValue.Text = voQueueDump.Queue.Index[i].MachineID;
                                break;
                            case 8:
                                lblIndex8ConfigurationMachineIDValue.Text = voQueueDump.Queue.Index[i].MachineID;
                                break;
                            case 9:
                                lblIndex9ConfigurationMachineIDValue.Text = voQueueDump.Queue.Index[i].MachineID;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0ConfigurationMachineIDValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1ConfigurationMachineIDValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2ConfigurationMachineIDValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3ConfigurationMachineIDValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4ConfigurationMachineIDValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5ConfigurationMachineIDValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6ConfigurationMachineIDValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7ConfigurationMachineIDValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8ConfigurationMachineIDValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9ConfigurationMachineIDValue.Text = "n/a";
                                break;
                        }
                    }
                    // <passkey>6a3c4256cb2624300705eaf5b42a631e</passkey>
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].Passkey))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0ConfigurationPasskeyValue.Text = voQueueDump.Queue.Index[i].Passkey;
                                break;
                            case 1:
                                lblIndex1ConfigurationPasskeyValue.Text = voQueueDump.Queue.Index[i].Passkey;
                                break;
                            case 2:
                                lblIndex2ConfigurationPasskeyValue.Text = voQueueDump.Queue.Index[i].Passkey;
                                break;
                            case 3:
                                lblIndex3ConfigurationPasskeyValue.Text = voQueueDump.Queue.Index[i].Passkey;
                                break;
                            case 4:
                                lblIndex4ConfigurationPasskeyValue.Text = voQueueDump.Queue.Index[i].Passkey;
                                break;
                            case 5:
                                lblIndex5ConfigurationPasskeyValue.Text = voQueueDump.Queue.Index[i].Passkey;
                                break;
                            case 6:
                                lblIndex6ConfigurationPasskeyValue.Text = voQueueDump.Queue.Index[i].Passkey;
                                break;
                            case 7:
                                lblIndex7ConfigurationPasskeyValue.Text = voQueueDump.Queue.Index[i].Passkey;
                                break;
                            case 8:
                                lblIndex8ConfigurationPasskeyValue.Text = voQueueDump.Queue.Index[i].Passkey;
                                break;
                            case 9:
                                lblIndex9ConfigurationPasskeyValue.Text = voQueueDump.Queue.Index[i].Passkey;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0ConfigurationPasskeyValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1ConfigurationPasskeyValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2ConfigurationPasskeyValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3ConfigurationPasskeyValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4ConfigurationPasskeyValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5ConfigurationPasskeyValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6ConfigurationPasskeyValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7ConfigurationPasskeyValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8ConfigurationPasskeyValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9ConfigurationPasskeyValue.Text = "n/a";
                                break;
                        }
                    }

                    // CS: 171.67.89.100; upload failures: 1; P limit: 5241856
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].CollectionServer))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0ExtraInfoCollectionServerValue.Text = voQueueDump.Queue.Index[i].CollectionServer;
                                break;
                            case 1:
                                lblIndex1ExtraInfoCollectionServerValue.Text = voQueueDump.Queue.Index[i].CollectionServer;
                                break;
                            case 2:
                                lblIndex2ExtraInfoCollectionServerValue.Text = voQueueDump.Queue.Index[i].CollectionServer;
                                break;
                            case 3:
                                lblIndex3ExtraInfoCollectionServerValue.Text = voQueueDump.Queue.Index[i].CollectionServer;
                                break;
                            case 4:
                                lblIndex4ExtraInfoCollectionServerValue.Text = voQueueDump.Queue.Index[i].CollectionServer;
                                break;
                            case 5:
                                lblIndex5ExtraInfoCollectionServerValue.Text = voQueueDump.Queue.Index[i].CollectionServer;
                                break;
                            case 6:
                                lblIndex6ExtraInfoCollectionServerValue.Text = voQueueDump.Queue.Index[i].CollectionServer;
                                break;
                            case 7:
                                lblIndex7ExtraInfoCollectionServerValue.Text = voQueueDump.Queue.Index[i].CollectionServer;
                                break;
                            case 8:
                                lblIndex8ExtraInfoCollectionServerValue.Text = voQueueDump.Queue.Index[i].CollectionServer;
                                break;
                            case 9:
                                lblIndex9ExtraInfoCollectionServerValue.Text = voQueueDump.Queue.Index[i].CollectionServer;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0ExtraInfoCollectionServerValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1ExtraInfoCollectionServerValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2ExtraInfoCollectionServerValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3ExtraInfoCollectionServerValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4ExtraInfoCollectionServerValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5ExtraInfoCollectionServerValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6ExtraInfoCollectionServerValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7ExtraInfoCollectionServerValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8ExtraInfoCollectionServerValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9ExtraInfoCollectionServerValue.Text = "n/a";
                                break;
                        }
                    }
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].UploadFailures))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0ExtraInfoUploadFailuresValue.Text = voQueueDump.Queue.Index[i].UploadFailures;
                                break;
                            case 1:
                                lblIndex1ExtraInfoUploadFailuresValue.Text = voQueueDump.Queue.Index[i].UploadFailures;
                                break;
                            case 2:
                                lblIndex2ExtraInfoUploadFailuresValue.Text = voQueueDump.Queue.Index[i].UploadFailures;
                                break;
                            case 3:
                                lblIndex3ExtraInfoUploadFailuresValue.Text = voQueueDump.Queue.Index[i].UploadFailures;
                                break;
                            case 4:
                                lblIndex4ExtraInfoUploadFailuresValue.Text = voQueueDump.Queue.Index[i].UploadFailures;
                                break;
                            case 5:
                                lblIndex5ExtraInfoUploadFailuresValue.Text = voQueueDump.Queue.Index[i].UploadFailures;
                                break;
                            case 6:
                                lblIndex6ExtraInfoUploadFailuresValue.Text = voQueueDump.Queue.Index[i].UploadFailures;
                                break;
                            case 7:
                                lblIndex7ExtraInfoUploadFailuresValue.Text = voQueueDump.Queue.Index[i].UploadFailures;
                                break;
                            case 8:
                                lblIndex8ExtraInfoUploadFailuresValue.Text = voQueueDump.Queue.Index[i].UploadFailures;
                                break;
                            case 9:
                                lblIndex9ExtraInfoUploadFailuresValue.Text = voQueueDump.Queue.Index[i].UploadFailures;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0ExtraInfoUploadFailuresValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1ExtraInfoUploadFailuresValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2ExtraInfoUploadFailuresValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3ExtraInfoUploadFailuresValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4ExtraInfoUploadFailuresValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5ExtraInfoUploadFailuresValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6ExtraInfoUploadFailuresValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7ExtraInfoUploadFailuresValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8ExtraInfoUploadFailuresValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9ExtraInfoUploadFailuresValue.Text = "n/a";
                                break;
                        }
                    }
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].PacketSizeLimit))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0ExtraInfoPacketSizeLimitValue.Text = voQueueDump.Queue.Index[i].PacketSizeLimit;
                                break;
                            case 1:
                                lblIndex1ExtraInfoPacketSizeLimitValue.Text = voQueueDump.Queue.Index[i].PacketSizeLimit;
                                break;
                            case 2:
                                lblIndex2ExtraInfoPacketSizeLimitValue.Text = voQueueDump.Queue.Index[i].PacketSizeLimit;
                                break;
                            case 3:
                                lblIndex3ExtraInfoPacketSizeLimitValue.Text = voQueueDump.Queue.Index[i].PacketSizeLimit;
                                break;
                            case 4:
                                lblIndex4ExtraInfoPacketSizeLimitValue.Text = voQueueDump.Queue.Index[i].PacketSizeLimit;
                                break;
                            case 5:
                                lblIndex5ExtraInfoPacketSizeLimitValue.Text = voQueueDump.Queue.Index[i].PacketSizeLimit;
                                break;
                            case 6:
                                lblIndex6ExtraInfoPacketSizeLimitValue.Text = voQueueDump.Queue.Index[i].PacketSizeLimit;
                                break;
                            case 7:
                                lblIndex7ExtraInfoPacketSizeLimitValue.Text = voQueueDump.Queue.Index[i].PacketSizeLimit;
                                break;
                            case 8:
                                lblIndex8ExtraInfoPacketSizeLimitValue.Text = voQueueDump.Queue.Index[i].PacketSizeLimit;
                                break;
                            case 9:
                                lblIndex9ExtraInfoPacketSizeLimitValue.Text = voQueueDump.Queue.Index[i].PacketSizeLimit;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0ExtraInfoPacketSizeLimitValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1ExtraInfoPacketSizeLimitValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2ExtraInfoPacketSizeLimitValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3ExtraInfoPacketSizeLimitValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4ExtraInfoPacketSizeLimitValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5ExtraInfoPacketSizeLimitValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6ExtraInfoPacketSizeLimitValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7ExtraInfoPacketSizeLimitValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8ExtraInfoPacketSizeLimitValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9ExtraInfoPacketSizeLimitValue.Text = "n/a";
                                break;
                        }
                    }
                    // DL: Sat Sep 18 01:47:09 2004; upload failures: 1; P limit: 5241856
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].DownloadTimestamp))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0ExtraInfoDownloadedValue.Text = voQueueDump.Queue.Index[i].DownloadTimestamp;
                                break;
                            case 1:
                                lblIndex1ExtraInfoDownloadedValue.Text = voQueueDump.Queue.Index[i].DownloadTimestamp;
                                break;
                            case 2:
                                lblIndex2ExtraInfoDownloadedValue.Text = voQueueDump.Queue.Index[i].DownloadTimestamp;
                                break;
                            case 3:
                                lblIndex3ExtraInfoDownloadedValue.Text = voQueueDump.Queue.Index[i].DownloadTimestamp;
                                break;
                            case 4:
                                lblIndex4ExtraInfoDownloadedValue.Text = voQueueDump.Queue.Index[i].DownloadTimestamp;
                                break;
                            case 5:
                                lblIndex5ExtraInfoDownloadedValue.Text = voQueueDump.Queue.Index[i].DownloadTimestamp;
                                break;
                            case 6:
                                lblIndex6ExtraInfoDownloadedValue.Text = voQueueDump.Queue.Index[i].DownloadTimestamp;
                                break;
                            case 7:
                                lblIndex7ExtraInfoDownloadedValue.Text = voQueueDump.Queue.Index[i].DownloadTimestamp;
                                break;
                            case 8:
                                lblIndex8ExtraInfoDownloadedValue.Text = voQueueDump.Queue.Index[i].DownloadTimestamp;
                                break;
                            case 9:
                                lblIndex9ExtraInfoDownloadedValue.Text = voQueueDump.Queue.Index[i].DownloadTimestamp;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0ExtraInfoDownloadedValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1ExtraInfoDownloadedValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2ExtraInfoDownloadedValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3ExtraInfoDownloadedValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4ExtraInfoDownloadedValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5ExtraInfoDownloadedValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6ExtraInfoDownloadedValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7ExtraInfoDownloadedValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8ExtraInfoDownloadedValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9ExtraInfoDownloadedValue.Text = "n/a";
                                break;
                        }
                    }

                    // work/wudata_07.dat file size: 197433; WU type: Folding@Home
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].WorkUnit.File))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0WorkUnitFileValue.Text = voQueueDump.Queue.Index[i].WorkUnit.File;
                                break;
                            case 1:
                                lblIndex1WorkUnitFileValue.Text = voQueueDump.Queue.Index[i].WorkUnit.File;
                                break;
                            case 2:
                                lblIndex2WorkUnitFileValue.Text = voQueueDump.Queue.Index[i].WorkUnit.File;
                                break;
                            case 3:
                                lblIndex3WorkUnitFileValue.Text = voQueueDump.Queue.Index[i].WorkUnit.File;
                                break;
                            case 4:
                                lblIndex4WorkUnitFileValue.Text = voQueueDump.Queue.Index[i].WorkUnit.File;
                                break;
                            case 5:
                                lblIndex5WorkUnitFileValue.Text = voQueueDump.Queue.Index[i].WorkUnit.File;
                                break;
                            case 6:
                                lblIndex6WorkUnitFileValue.Text = voQueueDump.Queue.Index[i].WorkUnit.File;
                                break;
                            case 7:
                                lblIndex7WorkUnitFileValue.Text = voQueueDump.Queue.Index[i].WorkUnit.File;
                                break;
                            case 8:
                                lblIndex8WorkUnitFileValue.Text = voQueueDump.Queue.Index[i].WorkUnit.File;
                                break;
                            case 9:
                                lblIndex9WorkUnitFileValue.Text = voQueueDump.Queue.Index[i].WorkUnit.File;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0WorkUnitFileValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1WorkUnitFileValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2WorkUnitFileValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3WorkUnitFileValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4WorkUnitFileValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5WorkUnitFileValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6WorkUnitFileValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7WorkUnitFileValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8WorkUnitFileValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9WorkUnitFileValue.Text = "n/a";
                                break;
                        }
                    }
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].WorkUnit.Size))
                    {
                        StringBuilder oString = new StringBuilder(voQueueDump.Queue.Index[i].WorkUnit.Size);
                        oString.Append(" bytes");

                        switch (i)
                        {
                            case 0:
                                lblIndex0WorkUnitSizeValue.Text = oString.ToString();
                                break;
                            case 1:
                                lblIndex1WorkUnitSizeValue.Text = oString.ToString();
                                break;
                            case 2:
                                lblIndex2WorkUnitSizeValue.Text = oString.ToString();
                                break;
                            case 3:
                                lblIndex3WorkUnitSizeValue.Text = oString.ToString();
                                break;
                            case 4:
                                lblIndex4WorkUnitSizeValue.Text = oString.ToString();
                                break;
                            case 5:
                                lblIndex5WorkUnitSizeValue.Text = oString.ToString();
                                break;
                            case 6:
                                lblIndex6WorkUnitSizeValue.Text = oString.ToString();
                                break;
                            case 7:
                                lblIndex7WorkUnitSizeValue.Text = oString.ToString();
                                break;
                            case 8:
                                lblIndex8WorkUnitSizeValue.Text = oString.ToString();
                                break;
                            case 9:
                                lblIndex9WorkUnitSizeValue.Text = oString.ToString();
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0WorkUnitSizeValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1WorkUnitSizeValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2WorkUnitSizeValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3WorkUnitSizeValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4WorkUnitSizeValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5WorkUnitSizeValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6WorkUnitSizeValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7WorkUnitSizeValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8WorkUnitSizeValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9WorkUnitSizeValue.Text = "n/a";
                                break;
                        }
                    }
                    if (!String.IsNullOrEmpty(voQueueDump.Queue.Index[i].WorkUnit.Type))
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0WorkUnitTypeValue.Text = voQueueDump.Queue.Index[i].WorkUnit.Type;
                                break;
                            case 1:
                                lblIndex1WorkUnitTypeValue.Text = voQueueDump.Queue.Index[i].WorkUnit.Type;
                                break;
                            case 2:
                                lblIndex2WorkUnitTypeValue.Text = voQueueDump.Queue.Index[i].WorkUnit.Type;
                                break;
                            case 3:
                                lblIndex3WorkUnitTypeValue.Text = voQueueDump.Queue.Index[i].WorkUnit.Type;
                                break;
                            case 4:
                                lblIndex4WorkUnitTypeValue.Text = voQueueDump.Queue.Index[i].WorkUnit.Type;
                                break;
                            case 5:
                                lblIndex5WorkUnitTypeValue.Text = voQueueDump.Queue.Index[i].WorkUnit.Type;
                                break;
                            case 6:
                                lblIndex6WorkUnitTypeValue.Text = voQueueDump.Queue.Index[i].WorkUnit.Type;
                                break;
                            case 7:
                                lblIndex7WorkUnitTypeValue.Text = voQueueDump.Queue.Index[i].WorkUnit.Type;
                                break;
                            case 8:
                                lblIndex8WorkUnitTypeValue.Text = voQueueDump.Queue.Index[i].WorkUnit.Type;
                                break;
                            case 9:
                                lblIndex9WorkUnitTypeValue.Text = voQueueDump.Queue.Index[i].WorkUnit.Type;
                                break;
                        }
                    }
                    else
                    {
                        switch (i)
                        {
                            case 0:
                                lblIndex0WorkUnitTypeValue.Text = "n/a";
                                break;
                            case 1:
                                lblIndex1WorkUnitTypeValue.Text = "n/a";
                                break;
                            case 2:
                                lblIndex2WorkUnitTypeValue.Text = "n/a";
                                break;
                            case 3:
                                lblIndex3WorkUnitTypeValue.Text = "n/a";
                                break;
                            case 4:
                                lblIndex4WorkUnitTypeValue.Text = "n/a";
                                break;
                            case 5:
                                lblIndex5WorkUnitTypeValue.Text = "n/a";
                                break;
                            case 6:
                                lblIndex6WorkUnitTypeValue.Text = "n/a";
                                break;
                            case 7:
                                lblIndex7WorkUnitTypeValue.Text = "n/a";
                                break;
                            case 8:
                                lblIndex8WorkUnitTypeValue.Text = "n/a";
                                break;
                            case 9:
                                lblIndex9WorkUnitTypeValue.Text = "n/a";
                                break;
                        }
                    }
                }
            }

            #endregion Queue Indices

            #region Queue Suffix

            // performance fraction container
            //
            // <performance_fraction>
            //   <fraction>0.943336</fraction>
            //   <units>4</units>
            // </performance_fraction>
            if (!String.IsNullOrEmpty(voQueueDump.Queue.PerformanceFraction.Fraction))
            {
                lblPerformanceFractionFractionValue.Text = voQueueDump.Queue.PerformanceFraction.Fraction;
            }
            else
            {
                lblPerformanceFractionFractionValue.Text = "n/a";
            }
            if (!String.IsNullOrEmpty(voQueueDump.Queue.PerformanceFraction.Units))
            {
                lblPerformanceFractionUnitsValue.Text = voQueueDump.Queue.PerformanceFraction.Units;
            }
            else
            {
                lblPerformanceFractionUnitsValue.Text = "n/a";
            }

            // download rate container
            //
            // <download_rate>
            //   <speed>288.028 KB/s</speed>
            //   <units>4</units>
            // </download_rate>
            if (!String.IsNullOrEmpty(voQueueDump.Queue.DownloadRate.Speed))
            {
                lblDownloadRateSpeedValue.Text = voQueueDump.Queue.DownloadRate.Speed;
            }
            else
            {
                lblDownloadRateSpeedValue.Text = "n/a";
            }
            if (!String.IsNullOrEmpty(voQueueDump.Queue.DownloadRate.Units))
            {
                lblDownloadRateUnitsValue.Text = voQueueDump.Queue.DownloadRate.Units;
            }
            else
            {
                lblDownloadRateUnitsValue.Text = "n/a";
            }

            // upload rate container
            //
            // <upload_rate>
            //   <speed>67.406 KB/s</speed>
            //   <units>4</units>
            // </upload_rate>
            if (!String.IsNullOrEmpty(voQueueDump.Queue.UploadRate.Speed))
            {
                lblUploadRateSpeedValue.Text = voQueueDump.Queue.UploadRate.Speed;
            }
            else
            {
                lblUploadRateSpeedValue.Text = "n/a";
            }
            if (!String.IsNullOrEmpty(voQueueDump.Queue.UploadRate.Units))
            {
                lblUploadRateUnitsValue.Text = voQueueDump.Queue.UploadRate.Units;
            }
            else
            {

                lblUploadRateUnitsValue.Text = "n/a";
            }

            // point projection container
            //
            // <pph>2.932</pph>
            if (!String.IsNullOrEmpty(voQueueDump.Queue.PPH))
            {
                lblPointsPerHourValue.Text = voQueueDump.Queue.PPH;
            }
            else
            {
                lblPointsPerHourValue.Text = "n/a";
            }
            // <ppd>70.38</ppd>
            if (!String.IsNullOrEmpty(voQueueDump.Queue.PPD))
            {
                lblPointsPerDayValue.Text = voQueueDump.Queue.PPD;
            }
            else
            {
                lblPointsPerDayValue.Text = "n/a";
            }
            // <ppw>492.6</ppw>
            if (!String.IsNullOrEmpty(voQueueDump.Queue.PPW))
            {
                lblPointsPerWeekValue.Text = voQueueDump.Queue.PPW;
            }
            else
            {
                lblPointsPerWeekValue.Text = "n/a";
            }
            // <ppy>25704</ppy>
            if (!String.IsNullOrEmpty(voQueueDump.Queue.PPY))
            {
                lblPointsPerYearValue.Text = voQueueDump.Queue.PPY;
            }
            else
            {
                lblPointsPerYearValue.Text = "n/a";
            }

            #endregion Queue Suffix
        }

        private void PopupNotice(QueueDump voQueueDump)
        {
            if (voQueueDump.Notice.Count > 0)
            {
                StringBuilder oString = new StringBuilder();
                for (int i = 0; i < voQueueDump.Notice.Count; i++)
                {
                    oString.Append(voQueueDump.Notice[i]);
                    oString.Append("\r\n");
                }
                MessageBox.Show(oString.ToString(), "Notice");
            }
        }

        private void optionsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            OptionsWindow oOptionsWindow = new OptionsWindow();
            oOptionsWindow.Show();
        }

        private void closeToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void checkForUpdatesToolStripMenuItem_Click(object sender, EventArgs e)
        {
            WebUpdateWindow oWebUpdateWindow = new WebUpdateWindow();
            oWebUpdateWindow.Show();
        }

        private void aboutToolStripMenuItem_Click(object sender, EventArgs e)
        {
            AboutBox oAboutBox = new AboutBox();
            oAboutBox.Show();
        }

        public void txtFahDirectory_TextChanged(object sender, EventArgs e)
        {
            Properties.Settings.Default.FahDirectory = txtFahDirectory.Text;
            Properties.Settings.Default.Save();
        }

        private void txtQueueDumpFile_TextChanged(object sender, EventArgs e)
        {
            Properties.Settings.Default.QueueDumpFile = txtQueueDumpFile.Text;
            Properties.Settings.Default.Save();
        }
    }
}
